"""INTERNAL: Consolidated generated types.

DO NOT import from this module directly.
Use 'from adcp import Type' or 'from adcp.types import Type' instead.

This module consolidates all generated types from generated_poc/ into a single
namespace for convenience. The leading underscore signals this is private API.

Auto-generated by datamodel-code-generator from JSON schemas.
DO NOT EDIT MANUALLY.

Generated from: https://github.com/adcontextprotocol/adcp/tree/main/schemas
Generation date: 2026-02-28 18:37:35 UTC
"""

# ruff: noqa: E501, I001
from __future__ import annotations

# Import all types from generated_poc modules
from adcp.types.generated_poc.enums.action_source import ActionSource
from adcp.types.generated_poc.enums.adcp_domain import AdcpDomain
from adcp.types.generated_poc.enums.age_verification_method import AgeVerificationMethod
from adcp.types.generated_poc.enums.asset_content_type import AssetContentType
from adcp.types.generated_poc.enums.attribution_model import AttributionModel
from adcp.types.generated_poc.enums.audience_source import AudienceSource
from adcp.types.generated_poc.enums.auth_scheme import AuthenticationScheme
from adcp.types.generated_poc.enums.available_metric import AvailableMetric
from adcp.types.generated_poc.enums.catalog_action import CatalogAction
from adcp.types.generated_poc.enums.catalog_item_status import CatalogItemStatus
from adcp.types.generated_poc.enums.catalog_type import CatalogType
from adcp.types.generated_poc.enums.channels import MediaChannel
from adcp.types.generated_poc.enums.co_branding_requirement import CoBrandingRequirement
from adcp.types.generated_poc.enums.consent_basis import ConsentBasis
from adcp.types.generated_poc.enums.content_id_type import ContentIdType
from adcp.types.generated_poc.enums.creative_action import CreativeAction
from adcp.types.generated_poc.enums.creative_agent_capability import CreativeAgentCapability
from adcp.types.generated_poc.enums.creative_approval_status import CreativeApprovalStatus
from adcp.types.generated_poc.enums.creative_sort_field import CreativeSortField
from adcp.types.generated_poc.enums.creative_status import CreativeStatus
from adcp.types.generated_poc.enums.daast_tracking_event import DaastTrackingEvent
from adcp.types.generated_poc.enums.daast_version import DaastVersion
from adcp.types.generated_poc.enums.day_of_week import DayOfWeek
from adcp.types.generated_poc.enums.delivery_type import DeliveryType
from adcp.types.generated_poc.enums.demographic_system import DemographicSystem
from adcp.types.generated_poc.enums.device_platform import DevicePlatform
from adcp.types.generated_poc.enums.device_type import DeviceType
from adcp.types.generated_poc.enums.digital_source_type import DigitalSourceType
from adcp.types.generated_poc.enums.dimension_unit import DimensionUnit
from adcp.types.generated_poc.enums.disclosure_position import DisclosurePosition
from adcp.types.generated_poc.enums.distance_unit import DistanceUnit
from adcp.types.generated_poc.enums.error_code import ErrorCode
from adcp.types.generated_poc.enums.event_type import EventType
from adcp.types.generated_poc.enums.feed_format import FeedFormat
from adcp.types.generated_poc.enums.feedback_source import FeedbackSource
from adcp.types.generated_poc.enums.forecast_method import ForecastMethod
from adcp.types.generated_poc.enums.forecast_range_unit import ForecastRangeUnit
from adcp.types.generated_poc.enums.forecastable_metric import ForecastableMetric
from adcp.types.generated_poc.enums.format_category import FormatCategory
from adcp.types.generated_poc.enums.format_id_parameter import FormatIdParameter
from adcp.types.generated_poc.enums.frequency_cap_scope import FrequencyCapScope
from adcp.types.generated_poc.enums.geo_level import GeographicTargetingLevel
from adcp.types.generated_poc.enums.history_entry_type import HistoryEntryType
from adcp.types.generated_poc.enums.http_method import HttpMethod
from adcp.types.generated_poc.enums.identifier_types import PropertyIdentifierTypes
from adcp.types.generated_poc.enums.javascript_module_type import JavascriptModuleType
from adcp.types.generated_poc.enums.landing_page_requirement import LandingPageRequirement
from adcp.types.generated_poc.enums.markdown_flavor import MarkdownFlavor
from adcp.types.generated_poc.enums.media_buy_status import MediaBuyStatus
from adcp.types.generated_poc.enums.metric_type import MetricType
from adcp.types.generated_poc.enums.metro_system import MetroAreaSystem
from adcp.types.generated_poc.enums.notification_type import NotificationType
from adcp.types.generated_poc.enums.pacing import Pacing
from adcp.types.generated_poc.enums.postal_system import PostalCodeSystem
from adcp.types.generated_poc.enums.preview_output_format import PreviewOutputFormat
from adcp.types.generated_poc.enums.pricing_model import PricingModel
from adcp.types.generated_poc.enums.property_type import PropertyType
from adcp.types.generated_poc.enums.publisher_identifier_types import PublisherIdentifierTypes
from adcp.types.generated_poc.enums.reach_unit import ReachUnit
from adcp.types.generated_poc.enums.reporting_frequency import ReportingFrequency
from adcp.types.generated_poc.enums.signal_catalog_type import SignalCatalogType
from adcp.types.generated_poc.enums.signal_source import SignalSource
from adcp.types.generated_poc.enums.signal_value_type import SignalValueType
from adcp.types.generated_poc.enums.sort_direction import SortDirection
from adcp.types.generated_poc.enums.sort_metric import SortMetric
from adcp.types.generated_poc.enums.task_status import TaskStatus
from adcp.types.generated_poc.enums.task_type import TaskType
from adcp.types.generated_poc.enums.transport_mode import TransportMode
from adcp.types.generated_poc.enums.uid_type import UidType
from adcp.types.generated_poc.enums.universal_macro import UniversalMacro
from adcp.types.generated_poc.enums.update_frequency import UpdateFrequency
from adcp.types.generated_poc.enums.url_asset_type import UrlAssetType
from adcp.types.generated_poc.enums.validation_mode import ValidationMode
from adcp.types.generated_poc.enums.vast_tracking_event import VastTrackingEvent
from adcp.types.generated_poc.enums.vast_version import VastVersion
from adcp.types.generated_poc.enums.wcag_level import WcagLevel
from adcp.types.generated_poc.enums.webhook_response_type import WebhookResponseType
from adcp.types.generated_poc.enums.webhook_security_method import WebhookSecurityMethod
from adcp.types.generated_poc.a2ui.component import A2UiComponent
from adcp.types.generated_poc.a2ui.surface import A2UiSurface
from adcp.types.generated_poc.account.get_account_financials_request import (
    GetAccountFinancialsRequest,
)
from adcp.types.generated_poc.account.get_account_financials_response import (
    Balance,
    Credit,
    GetAccountFinancialsResponse,
    GetAccountFinancialsResponse1,
    GetAccountFinancialsResponse2,
    Invoice,
    LastTopUp,
    PaymentStatus,
    Spend,
    Status,
)
from adcp.types.generated_poc.account.list_accounts_request import ListAccountsRequest
from adcp.types.generated_poc.account.list_accounts_response import ListAccountsResponse
from adcp.types.generated_poc.account.report_usage_request import ReportUsageRequest, UsageItem
from adcp.types.generated_poc.account.report_usage_response import ReportUsageResponse
from adcp.types.generated_poc.account.sync_accounts_request import (
    Account,
    Billing,
    SyncAccountsRequest,
)
from adcp.types.generated_poc.account.sync_accounts_response import (
    AccountScope,
    Action,
    CreditLimit,
    Setup,
    SyncAccountsResponse,
    SyncAccountsResponse1,
    SyncAccountsResponse2,
)
from adcp.types.generated_poc.adagents import (
    AdcpAgentsAuthorization,
    AdcpAgentsAuthorization1,
    AdcpAgentsAuthorization2,
    AuthorizedAgents,
    AuthorizedAgents1,
    AuthorizedAgents2,
    AuthorizedAgents3,
    AuthorizedAgents4,
    AuthorizedAgents5,
    Contact,
    PropertyFeature,
    SignalId,
    SignalTag,
    SignalTags,
    Tags,
)
from adcp.types.generated_poc.brand import (
    AgenticCheckout,
    Architecture,
    Asset,
    AuthorizedOperator,
    Avatar,
    Background,
    Brand,
    Brand1,
    BrandAgent,
    BrandDiscovery,
    BrandDiscovery1,
    BrandDiscovery2,
    BrandDiscovery3,
    BrandDiscovery4,
    BrandId,
    ColorValue,
    ColorValue1,
    ColorValue2,
    ColorValue2Item,
    Colors,
    Contact1,
    Country,
    Disclaimer,
    Domain,
    Fonts,
    House,
    KellerType,
    LocalizedName,
    Logo,
    Orientation,
    ProductCatalog,
    Property,
    Store,
    Tone,
    Trademark,
    Type,
    Variant,
    Voice,
)
from adcp.types.generated_poc.content_standards.artifact import (
    Artifact,
    AssetAccess,
    AssetAccess1,
    AssetAccess2,
    AssetAccess3,
    Assets,
    Assets1,
    Assets2,
    Assets3,
    Identifiers,
    Metadata,
    Provider,
    Role,
    TranscriptSource,
    TranscriptSource1,
)
from adcp.types.generated_poc.content_standards.artifact_webhook_payload import (
    ArtifactWebhookPayload,
    Pagination,
)
from adcp.types.generated_poc.content_standards.calibrate_content_request import (
    CalibrateContentRequest,
)
from adcp.types.generated_poc.content_standards.calibrate_content_response import (
    CalibrateContentResponse,
    CalibrateContentResponse1,
    CalibrateContentResponse2,
    Feature,
    Verdict,
)
from adcp.types.generated_poc.content_standards.content_standards import (
    CalibrationExemplars,
    ContentStandards,
)
from adcp.types.generated_poc.content_standards.create_content_standards_request import (
    CreateContentStandardsRequest,
    Fail,
    Pass,
    Scope,
)
from adcp.types.generated_poc.content_standards.create_content_standards_response import (
    CreateContentStandardsResponse,
    CreateContentStandardsResponse1,
    CreateContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.get_content_standards_request import (
    GetContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.get_content_standards_response import (
    GetContentStandardsResponse,
    GetContentStandardsResponse1,
    GetContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.get_media_buy_artifacts_request import (
    GetMediaBuyArtifactsRequest,
    Method,
    Sampling,
    TimeRange,
)
from adcp.types.generated_poc.content_standards.get_media_buy_artifacts_response import (
    BrandContext,
    GetMediaBuyArtifactsResponse,
    GetMediaBuyArtifactsResponse1,
    GetMediaBuyArtifactsResponse2,
    LocalVerdict,
    SamplingInfo,
)
from adcp.types.generated_poc.content_standards.list_content_standards_request import (
    ListContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.list_content_standards_response import (
    ListContentStandardsResponse,
    ListContentStandardsResponse1,
    ListContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.update_content_standards_request import (
    UpdateContentStandardsRequest,
)
from adcp.types.generated_poc.content_standards.update_content_standards_response import (
    UpdateContentStandardsResponse,
    UpdateContentStandardsResponse1,
    UpdateContentStandardsResponse2,
)
from adcp.types.generated_poc.content_standards.validate_content_delivery_request import (
    Record,
    ValidateContentDeliveryRequest,
)
from adcp.types.generated_poc.content_standards.validate_content_delivery_response import (
    Result,
    Summary,
    ValidateContentDeliveryResponse,
    ValidateContentDeliveryResponse1,
    ValidateContentDeliveryResponse2,
)
from adcp.types.generated_poc.core.account_ref import (
    AccountReference,
    AccountReference1,
    AccountReference2,
)
from adcp.types.generated_poc.core.activation_key import (
    ActivationKey,
    ActivationKey1,
    ActivationKey2,
)
from adcp.types.generated_poc.core.assets.audio_asset import AudioAsset, BitDepth, Channels
from adcp.types.generated_poc.core.assets.brief_asset import BriefAsset
from adcp.types.generated_poc.core.assets.catalog_asset import CatalogAsset
from adcp.types.generated_poc.core.assets.css_asset import CssAsset
from adcp.types.generated_poc.core.assets.daast_asset import DaastAsset, DaastAsset1, DaastAsset2
from adcp.types.generated_poc.core.assets.html_asset import Accessibility, HtmlAsset
from adcp.types.generated_poc.core.assets.image_asset import ImageAsset
from adcp.types.generated_poc.core.assets.javascript_asset import JavascriptAsset
from adcp.types.generated_poc.core.assets.markdown_asset import MarkdownAsset
from adcp.types.generated_poc.core.assets.text_asset import TextAsset
from adcp.types.generated_poc.core.assets.url_asset import UrlAsset
from adcp.types.generated_poc.core.assets.vast_asset import VastAsset, VastAsset1, VastAsset2
from adcp.types.generated_poc.core.assets.video_asset import (
    AudioBitDepth,
    AudioChannels,
    ChromaSubsampling,
    ColorSpace,
    FrameRateType,
    GopType,
    HdrFormat,
    MoovAtomPosition,
    ScanType,
    VideoAsset,
    VideoBitDepth,
)
from adcp.types.generated_poc.core.assets.webhook_asset import Security, WebhookAsset
from adcp.types.generated_poc.core.async_response_data import AdcpAsyncResponseData
from adcp.types.generated_poc.core.attribution_window import AttributionWindow
from adcp.types.generated_poc.core.audience_member import (
    AudienceMember,
    AudienceMember1,
    AudienceMember2,
    AudienceMember3,
    Uid,
)
from adcp.types.generated_poc.core.brand_ref import BrandReference
from adcp.types.generated_poc.core.catalog import Catalog, Gtin
from adcp.types.generated_poc.core.catalog_field_mapping import CatalogFieldMapping, Transform
from adcp.types.generated_poc.core.catchment import (
    Catchment,
    Catchment1,
    Catchment2,
    Catchment3,
    Geometry,
    Geometry1,
    Geometry2,
    Radius,
    TravelTime,
    TravelTime1,
    TravelTime2,
    Unit,
)
from adcp.types.generated_poc.core.context import ContextObject
from adcp.types.generated_poc.core.creative_asset import CreativeAsset, Input
from adcp.types.generated_poc.core.creative_assignment import CreativeAssignment
from adcp.types.generated_poc.core.creative_brief import (
    Compliance,
    CreativeBrief,
    Jurisdiction,
    Messaging,
    Objective,
    RequiredDisclosure,
)
from adcp.types.generated_poc.core.creative_filters import CreativeFilters
from adcp.types.generated_poc.core.creative_manifest import CreativeManifest
from adcp.types.generated_poc.core.creative_policy import CreativePolicy
from adcp.types.generated_poc.core.creative_variant import CreativeVariant, GenerationContext
from adcp.types.generated_poc.core.data_provider_signal_selector import (
    DataProviderSignalSelector,
    DataProviderSignalSelector1,
    DataProviderSignalSelector2,
    DataProviderSignalSelector3,
)
from adcp.types.generated_poc.core.date_range import DateRange
from adcp.types.generated_poc.core.datetime_range import DatetimeRange
from adcp.types.generated_poc.core.daypart_target import DaypartTarget
from adcp.types.generated_poc.core.delivery_forecast import DeliveryForecast
from adcp.types.generated_poc.core.delivery_metrics import (
    ByActionSourceItem,
    ByEventTypeItem,
    DeliveryMetrics,
    DoohMetrics,
    QuartileData,
    Standard,
    VenueBreakdownItem,
    Viewability,
)
from adcp.types.generated_poc.core.deployment import Deployment, Deployment1, Deployment2
from adcp.types.generated_poc.core.destination import Destination, Destination1, Destination2
from adcp.types.generated_poc.core.destination_item import (
    DestinationItem,
    DestinationType,
    Location,
)
from adcp.types.generated_poc.core.duration import Duration
from adcp.types.generated_poc.core.education_item import DegreeType, EducationItem, Level, Modality
from adcp.types.generated_poc.core.error import Error, Recovery
from adcp.types.generated_poc.core.event import Event
from adcp.types.generated_poc.core.event_custom_data import Content, EventCustomData
from adcp.types.generated_poc.core.ext import ExtensionObject
from adcp.types.generated_poc.core.flight_item import FlightItem, Origin
from adcp.types.generated_poc.core.forecast_point import ForecastPoint, Metrics
from adcp.types.generated_poc.core.forecast_range import ForecastRange
from adcp.types.generated_poc.core.format import (
    Assets10,
    Assets11,
    Assets12,
    Assets13,
    Assets14,
    Assets15,
    Assets16,
    Assets17,
    Assets18,
    Assets19,
    Assets20,
    Assets21,
    Assets22,
    Assets23,
    Assets24,
    Assets25,
    Assets26,
    Assets27,
    Assets28,
    Assets29,
    Assets30,
    Assets5,
    Assets6,
    Assets7,
    Assets8,
    Assets9,
    BaseGroupAsset,
    BaseIndividualAsset,
    Dimensions,
    Dimensions1,
    Format,
    FormatCard,
    FormatCardDetailed,
    Renders,
    Renders1,
    Responsive,
    SelectionMode,
)
from adcp.types.generated_poc.core.format_id import FormatId
from adcp.types.generated_poc.core.frequency_cap import (
    FrequencyCap,
    FrequencyCap1,
    FrequencyCap2,
    FrequencyCap3,
)
from adcp.types.generated_poc.core.geo_breakdown_support import GeographicBreakdownSupport
from adcp.types.generated_poc.core.hotel_item import Address, HotelItem
from adcp.types.generated_poc.core.identifier import Identifier
from adcp.types.generated_poc.core.job_item import (
    EmploymentType,
    ExperienceLevel,
    JobItem,
    Period,
    Salary,
)
from adcp.types.generated_poc.core.mcp_webhook_payload import McpWebhookPayload
from adcp.types.generated_poc.core.media_buy import MediaBuy
from adcp.types.generated_poc.core.media_buy_features import MediaBuyFeatures
from adcp.types.generated_poc.core.offering import GeoTargets, Metro, Offering, PostalArea, Region
from adcp.types.generated_poc.core.offering_asset_group import OfferingAssetGroup
from adcp.types.generated_poc.core.optimization_goal import (
    EventSource,
    Metric,
    OptimizationGoal,
    OptimizationGoal1,
    OptimizationGoal2,
    Target,
    Target1,
    Target2,
    Target3,
    Target4,
    TargetFrequency,
    TargetFrequency1,
)
from adcp.types.generated_poc.core.outcome_measurement import OutcomeMeasurement
from adcp.types.generated_poc.core.overlay import Bounds, Overlay, Visual
from adcp.types.generated_poc.core.pagination_request import PaginationRequest
from adcp.types.generated_poc.core.pagination_response import PaginationResponse
from adcp.types.generated_poc.core.performance_feedback import (
    MeasurementPeriod,
    PerformanceFeedback,
)
from adcp.types.generated_poc.core.placement import Placement
from adcp.types.generated_poc.core.price import Price
from adcp.types.generated_poc.core.pricing_option import PricingOption
from adcp.types.generated_poc.core.product import (
    CatalogMatch,
    ConversionTracking,
    DeliveryMeasurement,
    MatchedGtin,
    MetricOptimization,
    Product,
    ProductCard,
    ProductCardDetailed,
    SupportedMetric,
    SupportedTarget,
    SupportedTarget1,
    SupportedViewDuration,
)
from adcp.types.generated_poc.core.product_allocation import ProductAllocation
from adcp.types.generated_poc.core.product_filters import (
    BudgetRange,
    BudgetRange1,
    ProductFilters,
    RequiredGeoTargetingItem,
)
from adcp.types.generated_poc.core.property_id import PropertyId
from adcp.types.generated_poc.core.property_list_ref import PropertyListReference
from adcp.types.generated_poc.core.property_tag import PropertyTag
from adcp.types.generated_poc.core.proposal import Proposal, TotalBudgetGuidance
from adcp.types.generated_poc.core.protocol_envelope import ProtocolEnvelope
from adcp.types.generated_poc.core.provenance import (
    AiTool,
    C2pa,
    DeclaredBy,
    Disclosure,
    HumanOversight,
    Provenance,
    VerificationItem,
)
from adcp.types.generated_poc.core.publisher_property_selector import (
    PublisherPropertySelector,
    PublisherPropertySelector1,
    PublisherPropertySelector2,
    PublisherPropertySelector3,
)
from adcp.types.generated_poc.core.push_notification_config import (
    Authentication,
    PushNotificationConfig,
)
from adcp.types.generated_poc.core.real_estate_item import Area, ListingType, RealEstateItem
from adcp.types.generated_poc.core.reference_asset import ReferenceAsset
from adcp.types.generated_poc.core.reporting_capabilities import (
    DateRangeSupport,
    ReportingCapabilities,
)
from adcp.types.generated_poc.core.reporting_webhook import ReportingWebhook
from adcp.types.generated_poc.core.requirements.asset_requirements import AssetRequirements
from adcp.types.generated_poc.core.requirements.audio_asset_requirements import (
    AudioAssetRequirements,
    Channel,
    SampleRate,
)
from adcp.types.generated_poc.core.requirements.catalog_field_binding import (
    AssetPoolBinding,
    CatalogFieldBinding,
    CatalogFieldBinding1,
    ScalarBinding,
)
from adcp.types.generated_poc.core.requirements.catalog_requirements import CatalogRequirements
from adcp.types.generated_poc.core.requirements.css_asset_requirements import CssAssetRequirements
from adcp.types.generated_poc.core.requirements.daast_asset_requirements import (
    DaastAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.html_asset_requirements import (
    HtmlAssetRequirements,
    Sandbox,
)
from adcp.types.generated_poc.core.requirements.image_asset_requirements import (
    ImageAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.javascript_asset_requirements import (
    JavascriptAssetRequirements,
    ModuleType,
)
from adcp.types.generated_poc.core.requirements.markdown_asset_requirements import (
    MarkdownAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.offering_asset_constraint import (
    OfferingAssetConstraint,
)
from adcp.types.generated_poc.core.requirements.text_asset_requirements import TextAssetRequirements
from adcp.types.generated_poc.core.requirements.url_asset_requirements import (
    Protocol,
    UrlAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.vast_asset_requirements import VastAssetRequirements
from adcp.types.generated_poc.core.requirements.video_asset_requirements import (
    Codec,
    Container,
    FrameRate,
    VideoAssetRequirements,
)
from adcp.types.generated_poc.core.requirements.webhook_asset_requirements import (
    WebhookAssetRequirements,
)
from adcp.types.generated_poc.core.response import ProtocolResponse
from adcp.types.generated_poc.core.signal_definition import Range, SignalDefinition, Tag
from adcp.types.generated_poc.core.signal_filters import SignalFilters
from adcp.types.generated_poc.core.signal_id import SignalId2, SignalId3
from adcp.types.generated_poc.core.signal_pricing import (
    SignalPricing,
    SignalPricing1,
    SignalPricing2,
    SignalPricing3,
)
from adcp.types.generated_poc.core.signal_pricing_option import (
    SignalPricingOption,
    SignalPricingOption1,
    SignalPricingOption2,
    SignalPricingOption3,
    SignalPricingOption4,
    SignalPricingOption5,
    SignalPricingOption6,
    SignalPricingOption7,
)
from adcp.types.generated_poc.core.signal_targeting import (
    SignalTargeting,
    SignalTargeting1,
    SignalTargeting2,
    SignalTargeting3,
)
from adcp.types.generated_poc.core.start_timing import StartTiming
from adcp.types.generated_poc.core.store_item import StoreItem
from adcp.types.generated_poc.core.sub_asset import SubAsset, SubAsset1, SubAsset2
from adcp.types.generated_poc.core.targeting import (
    AgeRestriction,
    GeoCountriesExcludeItem,
    GeoCountry,
    GeoMetro,
    GeoMetrosExcludeItem,
    GeoPostalArea,
    GeoPostalAreasExcludeItem,
    GeoProximity,
    GeoProximity2,
    GeoProximity3,
    GeoRegion,
    GeoRegionsExcludeItem,
    Geometry4,
    Geometry5,
    KeywordTarget,
    LanguageItem,
    MatchType,
    NegativeKeyword,
    StoreCatchment,
    TargetingOverlay,
    TravelTime4,
    TravelTime5,
)
from adcp.types.generated_poc.core.user_match import (
    UserMatch,
    UserMatch1,
    UserMatch2,
    UserMatch3,
    UserMatch4,
    UserMatch5,
)
from adcp.types.generated_poc.core.vehicle_item import (
    BodyStyle,
    Condition,
    FuelType,
    Mileage,
    Transmission,
    VehicleItem,
)
from adcp.types.generated_poc.creative.creative_feature_result import CreativeFeatureResult
from adcp.types.generated_poc.creative.get_creative_delivery_request import (
    GetCreativeDeliveryRequest,
    GetCreativeDeliveryRequest1,
    GetCreativeDeliveryRequest2,
    GetCreativeDeliveryRequest3,
)
from adcp.types.generated_poc.creative.get_creative_delivery_response import (
    Creative,
    GetCreativeDeliveryResponse,
    ReportingPeriod,
)
from adcp.types.generated_poc.creative.get_creative_features_request import (
    GetCreativeFeaturesRequest,
)
from adcp.types.generated_poc.creative.get_creative_features_response import (
    GetCreativeFeaturesResponse,
    GetCreativeFeaturesResponse1,
    GetCreativeFeaturesResponse2,
)
from adcp.types.generated_poc.creative.list_creative_formats_request import (
    AssetType,
    ListCreativeFormatsRequestCreativeAgent,
)
from adcp.types.generated_poc.creative.list_creative_formats_response import (
    CreativeAgent,
    ListCreativeFormatsResponseCreativeAgent,
)
from adcp.types.generated_poc.creative.preview_creative_request import (
    Input2,
    PreviewCreativeRequest,
    PreviewCreativeRequest1,
    PreviewCreativeRequest2,
    PreviewCreativeRequest3,
    Request,
)
from adcp.types.generated_poc.creative.preview_creative_response import (
    Input4,
    Preview,
    Preview1,
    Preview2,
    Preview3,
    PreviewCreativeResponse,
    PreviewCreativeResponse1,
    PreviewCreativeResponse2,
    PreviewCreativeResponse3,
    Response,
    Response1,
    Results,
    Results1,
)
from adcp.types.generated_poc.creative.preview_render import (
    Embedding,
    PreviewRender,
    PreviewRender1,
    PreviewRender2,
    PreviewRender3,
)
from adcp.types.generated_poc.extensions.extension_meta import AdcpExtensionFileSchema
from adcp.types.generated_poc.media_buy.build_creative_request import BuildCreativeRequest
from adcp.types.generated_poc.media_buy.build_creative_response import (
    BuildCreativeResponse,
    BuildCreativeResponse1,
    BuildCreativeResponse2,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_input_required import (
    CreateMediaBuyInputRequired,
    Reason,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_submitted import (
    CreateMediaBuySubmitted,
)
from adcp.types.generated_poc.media_buy.create_media_buy_async_response_working import (
    CreateMediaBuyWorking,
)
from adcp.types.generated_poc.media_buy.create_media_buy_request import (
    ArtifactWebhook,
    BatchFrequency,
    CreateMediaBuyRequest,
    DeliveryMode,
    TotalBudget,
)
from adcp.types.generated_poc.media_buy.create_media_buy_response import (
    CreateMediaBuyResponse,
    CreateMediaBuyResponse1,
    CreateMediaBuyResponse2,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_request import (
    Geo,
    GetMediaBuyDeliveryRequest,
    ReportingDimensions,
    StatusFilter,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import (
    AggregatedTotals,
    ByAudienceItem,
    ByCatalogItemItem,
    ByCreativeItem,
    ByDevicePlatformItem,
    ByDeviceTypeItem,
    ByGeoItem,
    ByKeywordItem,
    ByPackageItem,
    ByPlacementItem,
    DailyBreakdownItem,
    DailyBreakdownItem1,
    GetMediaBuyDeliveryResponse,
    MediaBuyDelivery,
    Totals,
)
from adcp.types.generated_poc.media_buy.get_media_buys_request import GetMediaBuysRequest
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    CreativeApproval,
    GetMediaBuysResponse,
    Snapshot,
    SnapshotUnavailableReason,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_input_required import (
    GetProductsInputRequired,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_submitted import (
    GetProductsSubmitted,
)
from adcp.types.generated_poc.media_buy.get_products_async_response_working import (
    GetProductsWorking,
)
from adcp.types.generated_poc.media_buy.get_products_request import (
    Action2,
    BuyingMode,
    FieldModel,
    GetProductsRequest,
    GetProductsRequest1,
    GetProductsRequest2,
    GetProductsRequest3,
    Refine,
    Refine1,
    Refine2,
)
from adcp.types.generated_poc.media_buy.get_products_response import (
    GetProductsResponse,
    RefinementAppliedItem,
)
from adcp.types.generated_poc.media_buy.list_creative_formats_request import (
    ListCreativeFormatsRequest,
)
from adcp.types.generated_poc.media_buy.list_creative_formats_response import (
    ListCreativeFormatsResponse,
)
from adcp.types.generated_poc.media_buy.list_creatives_request import (
    Field1,
    ListCreativesRequest,
    Sort,
)
from adcp.types.generated_poc.media_buy.list_creatives_response import (
    AssignedPackage,
    Assignments,
    ListCreativesResponse,
    Performance,
    QuerySummary,
    SortApplied,
    StatusSummary,
)
from adcp.types.generated_poc.media_buy.log_event_request import LogEventRequest
from adcp.types.generated_poc.media_buy.log_event_response import (
    LogEventResponse,
    LogEventResponse1,
    LogEventResponse2,
    PartialFailure,
)
from adcp.types.generated_poc.media_buy.package_request import PackageRequest
from adcp.types.generated_poc.media_buy.package_update import (
    KeywordTargetsAddItem,
    KeywordTargetsAddItem1,
    KeywordTargetsRemoveItem,
    KeywordTargetsRemoveItem1,
    NegativeKeywordsAddItem,
    NegativeKeywordsAddItem1,
    NegativeKeywordsRemoveItem,
    NegativeKeywordsRemoveItem1,
    PackageUpdate,
    PackageUpdate1,
    PackageUpdate2,
)
from adcp.types.generated_poc.media_buy.provide_performance_feedback_request import (
    ProvidePerformanceFeedbackRequest,
    ProvidePerformanceFeedbackRequest1,
    ProvidePerformanceFeedbackRequest2,
)
from adcp.types.generated_poc.media_buy.provide_performance_feedback_response import (
    ProvidePerformanceFeedbackResponse,
    ProvidePerformanceFeedbackResponse1,
    ProvidePerformanceFeedbackResponse2,
)
from adcp.types.generated_poc.media_buy.sync_audiences_request import (
    AudienceType,
    SyncAudiencesRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_response import (
    SyncAudiencesResponse,
    SyncAudiencesResponse1,
    SyncAudiencesResponse2,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_input_required import (
    SyncCatalogsInputRequired,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_submitted import (
    SyncCatalogsSubmitted,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_async_response_working import (
    SyncCatalogsWorking,
)
from adcp.types.generated_poc.media_buy.sync_catalogs_request import SyncCatalogsRequest
from adcp.types.generated_poc.media_buy.sync_catalogs_response import (
    ItemIssue,
    SyncCatalogsResponse,
    SyncCatalogsResponse1,
    SyncCatalogsResponse2,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_input_required import (
    SyncCreativesInputRequired,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_submitted import (
    SyncCreativesSubmitted,
)
from adcp.types.generated_poc.media_buy.sync_creatives_async_response_working import (
    SyncCreativesWorking,
)
from adcp.types.generated_poc.media_buy.sync_creatives_request import (
    Assignment,
    SyncCreativesRequest,
)
from adcp.types.generated_poc.media_buy.sync_creatives_response import (
    SyncCreativesResponse,
    SyncCreativesResponse1,
    SyncCreativesResponse2,
)
from adcp.types.generated_poc.media_buy.sync_event_sources_request import SyncEventSourcesRequest
from adcp.types.generated_poc.media_buy.sync_event_sources_response import (
    ManagedBy,
    SnippetType,
    SyncEventSourcesResponse,
    SyncEventSourcesResponse1,
    SyncEventSourcesResponse2,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_input_required import (
    UpdateMediaBuyInputRequired,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_submitted import (
    UpdateMediaBuySubmitted,
)
from adcp.types.generated_poc.media_buy.update_media_buy_async_response_working import (
    UpdateMediaBuyWorking,
)
from adcp.types.generated_poc.media_buy.update_media_buy_request import (
    UpdateMediaBuyRequest,
    UpdateMediaBuyRequest1,
    UpdateMediaBuyRequest2,
)
from adcp.types.generated_poc.media_buy.update_media_buy_response import (
    UpdateMediaBuyResponse,
    UpdateMediaBuyResponse1,
    UpdateMediaBuyResponse2,
)
from adcp.types.generated_poc.pricing_options.cpa_option import CpaPricingOption
from adcp.types.generated_poc.pricing_options.cpc_option import CpcPricingOption
from adcp.types.generated_poc.pricing_options.cpcv_option import CpcvPricingOption
from adcp.types.generated_poc.pricing_options.cpm_option import CpmPricingOption
from adcp.types.generated_poc.pricing_options.cpp_option import CppPricingOption, Parameters
from adcp.types.generated_poc.pricing_options.cpv_option import (
    CpvPricingOption,
    ViewThreshold,
    ViewThreshold1,
)
from adcp.types.generated_poc.pricing_options.flat_rate_option import FlatRatePricingOption
from adcp.types.generated_poc.pricing_options.price_guidance import PriceGuidance
from adcp.types.generated_poc.pricing_options.time_option import TimeBasedPricingOption, TimeUnit
from adcp.types.generated_poc.pricing_options.vcpm_option import VcpmPricingOption
from adcp.types.generated_poc.property.base_property_source import (
    BasePropertySource,
    BasePropertySource1,
    BasePropertySource2,
    BasePropertySource3,
)
from adcp.types.generated_poc.property.create_property_list_request import CreatePropertyListRequest
from adcp.types.generated_poc.property.create_property_list_response import (
    CreatePropertyListResponse,
)
from adcp.types.generated_poc.property.delete_property_list_request import DeletePropertyListRequest
from adcp.types.generated_poc.property.delete_property_list_response import (
    DeletePropertyListResponse,
)
from adcp.types.generated_poc.property.feature_requirement import FeatureRequirement, IfNotCovered
from adcp.types.generated_poc.property.get_property_list_request import GetPropertyListRequest
from adcp.types.generated_poc.property.get_property_list_response import GetPropertyListResponse
from adcp.types.generated_poc.property.list_property_lists_request import ListPropertyListsRequest
from adcp.types.generated_poc.property.list_property_lists_response import ListPropertyListsResponse
from adcp.types.generated_poc.property.property_error import Code, PropertyError
from adcp.types.generated_poc.property.property_feature_definition import (
    Coverage,
    PropertyFeatureDefinition,
)
from adcp.types.generated_poc.property.property_list import PropertyList
from adcp.types.generated_poc.property.property_list_changed_webhook import (
    ChangeSummary,
    PropertyListChangedWebhook,
)
from adcp.types.generated_poc.property.property_list_filters import (
    CountriesAllItem,
    PropertyListFilters,
)
from adcp.types.generated_poc.property.update_property_list_request import UpdatePropertyListRequest
from adcp.types.generated_poc.property.update_property_list_response import (
    UpdatePropertyListResponse,
)
from adcp.types.generated_poc.protocol.get_adcp_capabilities_request import (
    GetAdcpCapabilitiesRequest,
)
from adcp.types.generated_poc.protocol.get_adcp_capabilities_response import (
    AccountResolution,
    Adcp,
    AudienceTargeting,
    AvailableDimension,
    CreativeFeature,
    CreativeSpecs,
    DataProviderDomain,
    Endpoint,
    Execution,
    ExtensionsSupportedItem,
    Features,
    GeoMetros,
    GeoPostalAreas,
    GetAdcpCapabilitiesResponse,
    Governance,
    KeywordTargets,
    MajorVersion,
    MatchingLatencyHours,
    MraidVersion,
    NegativeKeywords,
    Portfolio,
    Preferred,
    PrimaryCountry,
    PublisherDomain,
    Reporting,
    Signals,
    SponsoredIntelligence,
    SupportedBillingEnum,
    SupportedIdentifierType,
    SupportedMatchType,
    SupportedProtocol,
    Targeting,
    Transport,
)
from adcp.types.generated_poc.signals.activate_signal_request import ActivateSignalRequest
from adcp.types.generated_poc.signals.activate_signal_response import (
    ActivateSignalResponse,
    ActivateSignalResponse1,
    ActivateSignalResponse2,
)
from adcp.types.generated_poc.signals.get_signals_request import (
    GetSignalsRequest,
    GetSignalsRequest1,
    GetSignalsRequest2,
)
from adcp.types.generated_poc.signals.get_signals_response import GetSignalsResponse, Signal
from adcp.types.generated_poc.sponsored_intelligence.si_capabilities import (
    A2ui,
    Commerce,
    Components,
    Modalities,
    SiCapabilities,
    StandardEnum,
    Video,
)
from adcp.types.generated_poc.sponsored_intelligence.si_get_offering_request import (
    SiGetOfferingRequest,
)
from adcp.types.generated_poc.sponsored_intelligence.si_get_offering_response import (
    MatchingProduct,
    SiGetOfferingResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_identity import (
    ConsentScopeEnum,
    PrivacyPolicyAcknowledged,
    ShippingAddress,
    SiIdentity,
    User,
)
from adcp.types.generated_poc.sponsored_intelligence.si_initiate_session_request import (
    SiInitiateSessionRequest,
)
from adcp.types.generated_poc.sponsored_intelligence.si_initiate_session_response import (
    SiInitiateSessionResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_send_message_request import (
    ActionResponse,
    SiSendMessageRequest,
    SiSendMessageRequest1,
    SiSendMessageRequest2,
)
from adcp.types.generated_poc.sponsored_intelligence.si_send_message_response import (
    ContextForCheckout,
    Handoff,
    Intent,
    SessionStatus,
    SiSendMessageResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_terminate_session_request import (
    SiTerminateSessionRequest,
    TerminationContext,
    TransactionIntent,
)
from adcp.types.generated_poc.sponsored_intelligence.si_terminate_session_response import (
    AcpHandoff,
    FollowUp,
    SiTerminateSessionResponse,
)
from adcp.types.generated_poc.sponsored_intelligence.si_ui_element import SiUiElement

# Special imports for name collisions (qualified names for types defined in multiple modules)
from adcp.types.generated_poc.core.package import Package as _PackageFromPackage
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    Package as _PackageFromGetMediaBuysResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import (
    DeliveryStatus as _DeliveryStatusFromGetMediaBuyDeliveryResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buys_response import (
    DeliveryStatus as _DeliveryStatusFromGetMediaBuysResponse,
)
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_request import (
    Audience as _AudienceFromGetMediaBuyDeliveryRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_request import (
    Audience as _AudienceFromSyncAudiencesRequest,
)
from adcp.types.generated_poc.media_buy.sync_audiences_response import (
    Audience as _AudienceFromSyncAudiencesResponse,
)

# Backward compatibility aliases for renamed types
MediaBuyPackage = _PackageFromGetMediaBuysResponse
DeliveryStatus = _DeliveryStatusFromGetMediaBuysResponse

# Backwards-compat: Types removed from upstream schemas.
from adcp.types.base import AdCPBaseModel as _AdCPBaseModel
from enum import Enum as _Enum
from pydantic import ConfigDict as _ConfigDict


class BrandManifest(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# PromotedOfferings and related types are superseded by Catalog with type='offering'.
class PromotedOfferings(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class PromotedOfferingsAssetRequirements(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# Preserved as Enum (not model) so attribute access and iteration still work.
class PromotedOfferingsRequirement(str, _Enum):
    si_agent_url = "si_agent_url"
    offerings = "offerings"
    brand_logos = "brand.logos"
    brand_colors = "brand.colors"
    brand_tone = "brand.tone"
    brand_assets = "brand.assets"
    brand_product_catalog = "brand.product_catalog"


class PromotedProducts(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class AssetSelectors(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# DeliverTo was removed in upstream schemas (v2.5.x). The GetSignalsRequest wire
# format changed: 'deliver_to' nested object with 'deployments'+'countries' was
# replaced by top-level 'destinations' and 'countries' fields. Code using
# GetSignalsRequest(deliver_to=DeliverTo(...)) must migrate to the new field names.
# This stub prevents ImportError only; it cannot preserve the old wire behavior.
class DeliverTo(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class DeliverTo1(DeliverTo):
    pass


# Pricing was removed in upstream schemas (v2.5.x). Replaced by SignalPricingOption
# which has the same cpm/currency fields. This stub preserves imports only.
class Pricing(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# Measurement was renamed to OutcomeMeasurement upstream. This alias preserves imports.
Measurement = OutcomeMeasurement


# ListAuthorizedProperties was removed from upstream schemas.
# Replaced by adagents.json-based authorization model.
class ListAuthorizedPropertiesRequest(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


class ListAuthorizedPropertiesResponse(_AdCPBaseModel):
    model_config = _ConfigDict(extra="allow")


# PackageStatus enum was removed from upstream schemas.
class PackageStatus(str, _Enum):
    draft = "draft"
    active = "active"
    paused = "paused"
    completed = "completed"


# Explicit exports
__all__ = [
    "A2UiComponent",
    "A2UiSurface",
    "A2ui",
    "Accessibility",
    "Account",
    "AccountReference",
    "AccountReference1",
    "AccountReference2",
    "AccountResolution",
    "AccountScope",
    "AcpHandoff",
    "Action",
    "Action2",
    "ActionResponse",
    "ActionSource",
    "ActivateSignalRequest",
    "ActivateSignalResponse",
    "ActivateSignalResponse1",
    "ActivateSignalResponse2",
    "ActivationKey",
    "ActivationKey1",
    "ActivationKey2",
    "Adcp",
    "AdcpAgentsAuthorization",
    "AdcpAgentsAuthorization1",
    "AdcpAgentsAuthorization2",
    "AdcpAsyncResponseData",
    "AdcpDomain",
    "AdcpExtensionFileSchema",
    "Address",
    "AgeRestriction",
    "AgeVerificationMethod",
    "AgenticCheckout",
    "AggregatedTotals",
    "AiTool",
    "Architecture",
    "Area",
    "Artifact",
    "ArtifactWebhook",
    "ArtifactWebhookPayload",
    "Asset",
    "AssetAccess",
    "AssetAccess1",
    "AssetAccess2",
    "AssetAccess3",
    "AssetContentType",
    "AssetPoolBinding",
    "AssetRequirements",
    "AssetSelectors",
    "AssetType",
    "Assets",
    "Assets1",
    "Assets10",
    "Assets11",
    "Assets12",
    "Assets13",
    "Assets14",
    "Assets15",
    "Assets16",
    "Assets17",
    "Assets18",
    "Assets19",
    "Assets2",
    "Assets20",
    "Assets21",
    "Assets22",
    "Assets23",
    "Assets24",
    "Assets25",
    "Assets26",
    "Assets27",
    "Assets28",
    "Assets29",
    "Assets3",
    "Assets30",
    "Assets5",
    "Assets6",
    "Assets7",
    "Assets8",
    "Assets9",
    "AssignedPackage",
    "Assignment",
    "Assignments",
    "AttributionModel",
    "AttributionWindow",
    "AudienceMember",
    "AudienceMember1",
    "AudienceMember2",
    "AudienceMember3",
    "AudienceSource",
    "AudienceTargeting",
    "AudienceType",
    "AudioAsset",
    "AudioAssetRequirements",
    "AudioBitDepth",
    "AudioChannels",
    "Authentication",
    "AuthenticationScheme",
    "AuthorizedAgents",
    "AuthorizedAgents1",
    "AuthorizedAgents2",
    "AuthorizedAgents3",
    "AuthorizedAgents4",
    "AuthorizedAgents5",
    "AuthorizedOperator",
    "AvailableDimension",
    "AvailableMetric",
    "Avatar",
    "Background",
    "Balance",
    "BaseGroupAsset",
    "BaseIndividualAsset",
    "BasePropertySource",
    "BasePropertySource1",
    "BasePropertySource2",
    "BasePropertySource3",
    "BatchFrequency",
    "Billing",
    "BitDepth",
    "BodyStyle",
    "Bounds",
    "Brand",
    "Brand1",
    "BrandAgent",
    "BrandContext",
    "BrandDiscovery",
    "BrandDiscovery1",
    "BrandDiscovery2",
    "BrandDiscovery3",
    "BrandDiscovery4",
    "BrandId",
    "BrandManifest",
    "BrandReference",
    "BriefAsset",
    "BudgetRange",
    "BudgetRange1",
    "BuildCreativeRequest",
    "BuildCreativeResponse",
    "BuildCreativeResponse1",
    "BuildCreativeResponse2",
    "BuyingMode",
    "ByActionSourceItem",
    "ByAudienceItem",
    "ByCatalogItemItem",
    "ByCreativeItem",
    "ByDevicePlatformItem",
    "ByDeviceTypeItem",
    "ByEventTypeItem",
    "ByGeoItem",
    "ByKeywordItem",
    "ByPackageItem",
    "ByPlacementItem",
    "C2pa",
    "CalibrateContentRequest",
    "CalibrateContentResponse",
    "CalibrateContentResponse1",
    "CalibrateContentResponse2",
    "CalibrationExemplars",
    "Catalog",
    "CatalogAction",
    "CatalogAsset",
    "CatalogFieldBinding",
    "CatalogFieldBinding1",
    "CatalogFieldMapping",
    "CatalogItemStatus",
    "CatalogMatch",
    "CatalogRequirements",
    "CatalogType",
    "Catchment",
    "Catchment1",
    "Catchment2",
    "Catchment3",
    "ChangeSummary",
    "Channel",
    "Channels",
    "ChromaSubsampling",
    "CoBrandingRequirement",
    "Code",
    "Codec",
    "ColorSpace",
    "ColorValue",
    "ColorValue1",
    "ColorValue2",
    "ColorValue2Item",
    "Colors",
    "Commerce",
    "Compliance",
    "Components",
    "Condition",
    "ConsentBasis",
    "ConsentScopeEnum",
    "Contact",
    "Contact1",
    "Container",
    "Content",
    "ContentIdType",
    "ContentStandards",
    "ContextForCheckout",
    "ContextObject",
    "ConversionTracking",
    "CountriesAllItem",
    "Country",
    "Coverage",
    "CpaPricingOption",
    "CpcPricingOption",
    "CpcvPricingOption",
    "CpmPricingOption",
    "CppPricingOption",
    "CpvPricingOption",
    "CreateContentStandardsRequest",
    "CreateContentStandardsResponse",
    "CreateContentStandardsResponse1",
    "CreateContentStandardsResponse2",
    "CreateMediaBuyInputRequired",
    "CreateMediaBuyRequest",
    "CreateMediaBuyResponse",
    "CreateMediaBuyResponse1",
    "CreateMediaBuyResponse2",
    "CreateMediaBuySubmitted",
    "CreateMediaBuyWorking",
    "CreatePropertyListRequest",
    "CreatePropertyListResponse",
    "Creative",
    "CreativeAction",
    "CreativeAgent",
    "CreativeAgentCapability",
    "CreativeApproval",
    "CreativeApprovalStatus",
    "CreativeAsset",
    "CreativeAssignment",
    "CreativeBrief",
    "CreativeFeature",
    "CreativeFeatureResult",
    "CreativeFilters",
    "CreativeManifest",
    "CreativePolicy",
    "CreativeSortField",
    "CreativeSpecs",
    "CreativeStatus",
    "CreativeVariant",
    "Credit",
    "CreditLimit",
    "CssAsset",
    "CssAssetRequirements",
    "DaastAsset",
    "DaastAsset1",
    "DaastAsset2",
    "DaastAssetRequirements",
    "DaastTrackingEvent",
    "DaastVersion",
    "DailyBreakdownItem",
    "DailyBreakdownItem1",
    "DataProviderDomain",
    "DataProviderSignalSelector",
    "DataProviderSignalSelector1",
    "DataProviderSignalSelector2",
    "DataProviderSignalSelector3",
    "DateRange",
    "DateRangeSupport",
    "DatetimeRange",
    "DayOfWeek",
    "DaypartTarget",
    "DeclaredBy",
    "DegreeType",
    "DeletePropertyListRequest",
    "DeletePropertyListResponse",
    "DeliverTo",
    "DeliverTo1",
    "DeliveryForecast",
    "DeliveryMeasurement",
    "DeliveryMetrics",
    "DeliveryMode",
    "DeliveryStatus",
    "DeliveryType",
    "DemographicSystem",
    "Deployment",
    "Deployment1",
    "Deployment2",
    "Destination",
    "Destination1",
    "Destination2",
    "DestinationItem",
    "DestinationType",
    "DevicePlatform",
    "DeviceType",
    "DigitalSourceType",
    "DimensionUnit",
    "Dimensions",
    "Dimensions1",
    "Disclaimer",
    "Disclosure",
    "DisclosurePosition",
    "DistanceUnit",
    "Domain",
    "DoohMetrics",
    "Duration",
    "EducationItem",
    "Embedding",
    "EmploymentType",
    "Endpoint",
    "Error",
    "ErrorCode",
    "Event",
    "EventCustomData",
    "EventSource",
    "EventType",
    "Execution",
    "ExperienceLevel",
    "ExtensionObject",
    "ExtensionsSupportedItem",
    "Fail",
    "Feature",
    "FeatureRequirement",
    "Features",
    "FeedFormat",
    "FeedbackSource",
    "Field1",
    "FieldModel",
    "FlatRatePricingOption",
    "FlightItem",
    "FollowUp",
    "Fonts",
    "ForecastMethod",
    "ForecastPoint",
    "ForecastRange",
    "ForecastRangeUnit",
    "ForecastableMetric",
    "Format",
    "FormatCard",
    "FormatCardDetailed",
    "FormatCategory",
    "FormatId",
    "FormatIdParameter",
    "FrameRate",
    "FrameRateType",
    "FrequencyCap",
    "FrequencyCap1",
    "FrequencyCap2",
    "FrequencyCap3",
    "FrequencyCapScope",
    "FuelType",
    "GenerationContext",
    "Geo",
    "GeoCountriesExcludeItem",
    "GeoCountry",
    "GeoMetro",
    "GeoMetros",
    "GeoMetrosExcludeItem",
    "GeoPostalArea",
    "GeoPostalAreas",
    "GeoPostalAreasExcludeItem",
    "GeoProximity",
    "GeoProximity2",
    "GeoProximity3",
    "GeoRegion",
    "GeoRegionsExcludeItem",
    "GeoTargets",
    "GeographicBreakdownSupport",
    "GeographicTargetingLevel",
    "Geometry",
    "Geometry1",
    "Geometry2",
    "Geometry4",
    "Geometry5",
    "GetAccountFinancialsRequest",
    "GetAccountFinancialsResponse",
    "GetAccountFinancialsResponse1",
    "GetAccountFinancialsResponse2",
    "GetAdcpCapabilitiesRequest",
    "GetAdcpCapabilitiesResponse",
    "GetContentStandardsRequest",
    "GetContentStandardsResponse",
    "GetContentStandardsResponse1",
    "GetContentStandardsResponse2",
    "GetCreativeDeliveryRequest",
    "GetCreativeDeliveryRequest1",
    "GetCreativeDeliveryRequest2",
    "GetCreativeDeliveryRequest3",
    "GetCreativeDeliveryResponse",
    "GetCreativeFeaturesRequest",
    "GetCreativeFeaturesResponse",
    "GetCreativeFeaturesResponse1",
    "GetCreativeFeaturesResponse2",
    "GetMediaBuyArtifactsRequest",
    "GetMediaBuyArtifactsResponse",
    "GetMediaBuyArtifactsResponse1",
    "GetMediaBuyArtifactsResponse2",
    "GetMediaBuyDeliveryRequest",
    "GetMediaBuyDeliveryResponse",
    "GetMediaBuysRequest",
    "GetMediaBuysResponse",
    "GetProductsInputRequired",
    "GetProductsRequest",
    "GetProductsRequest1",
    "GetProductsRequest2",
    "GetProductsRequest3",
    "GetProductsResponse",
    "GetProductsSubmitted",
    "GetProductsWorking",
    "GetPropertyListRequest",
    "GetPropertyListResponse",
    "GetSignalsRequest",
    "GetSignalsRequest1",
    "GetSignalsRequest2",
    "GetSignalsResponse",
    "GopType",
    "Governance",
    "Gtin",
    "Handoff",
    "HdrFormat",
    "HistoryEntryType",
    "HotelItem",
    "House",
    "HtmlAsset",
    "HtmlAssetRequirements",
    "HttpMethod",
    "HumanOversight",
    "Identifier",
    "Identifiers",
    "IfNotCovered",
    "ImageAsset",
    "ImageAssetRequirements",
    "Input",
    "Input2",
    "Input4",
    "Intent",
    "Invoice",
    "ItemIssue",
    "JavascriptAsset",
    "JavascriptAssetRequirements",
    "JavascriptModuleType",
    "JobItem",
    "Jurisdiction",
    "KellerType",
    "KeywordTarget",
    "KeywordTargets",
    "KeywordTargetsAddItem",
    "KeywordTargetsAddItem1",
    "KeywordTargetsRemoveItem",
    "KeywordTargetsRemoveItem1",
    "LandingPageRequirement",
    "LanguageItem",
    "LastTopUp",
    "Level",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ListAuthorizedPropertiesRequest",
    "ListAuthorizedPropertiesResponse",
    "ListContentStandardsRequest",
    "ListContentStandardsResponse",
    "ListContentStandardsResponse1",
    "ListContentStandardsResponse2",
    "ListCreativeFormatsRequest",
    "ListCreativeFormatsRequestCreativeAgent",
    "ListCreativeFormatsResponse",
    "ListCreativeFormatsResponseCreativeAgent",
    "ListCreativesRequest",
    "ListCreativesResponse",
    "ListPropertyListsRequest",
    "ListPropertyListsResponse",
    "ListingType",
    "LocalVerdict",
    "LocalizedName",
    "Location",
    "LogEventRequest",
    "LogEventResponse",
    "LogEventResponse1",
    "LogEventResponse2",
    "Logo",
    "MajorVersion",
    "ManagedBy",
    "MarkdownAsset",
    "MarkdownAssetRequirements",
    "MarkdownFlavor",
    "MatchType",
    "MatchedGtin",
    "MatchingLatencyHours",
    "MatchingProduct",
    "McpWebhookPayload",
    "Measurement",
    "MeasurementPeriod",
    "MediaBuy",
    "MediaBuyDelivery",
    "MediaBuyFeatures",
    "MediaBuyPackage",
    "MediaBuyStatus",
    "MediaChannel",
    "Messaging",
    "Metadata",
    "Method",
    "Metric",
    "MetricOptimization",
    "MetricType",
    "Metrics",
    "Metro",
    "MetroAreaSystem",
    "Mileage",
    "Modalities",
    "Modality",
    "ModuleType",
    "MoovAtomPosition",
    "MraidVersion",
    "NegativeKeyword",
    "NegativeKeywords",
    "NegativeKeywordsAddItem",
    "NegativeKeywordsAddItem1",
    "NegativeKeywordsRemoveItem",
    "NegativeKeywordsRemoveItem1",
    "NotificationType",
    "Objective",
    "Offering",
    "OfferingAssetConstraint",
    "OfferingAssetGroup",
    "OptimizationGoal",
    "OptimizationGoal1",
    "OptimizationGoal2",
    "Orientation",
    "Origin",
    "OutcomeMeasurement",
    "Overlay",
    "Pacing",
    "PackageRequest",
    "PackageStatus",
    "PackageUpdate",
    "PackageUpdate1",
    "PackageUpdate2",
    "Pagination",
    "PaginationRequest",
    "PaginationResponse",
    "Parameters",
    "PartialFailure",
    "Pass",
    "PaymentStatus",
    "Performance",
    "PerformanceFeedback",
    "Period",
    "Placement",
    "Portfolio",
    "PostalArea",
    "PostalCodeSystem",
    "Preferred",
    "Preview",
    "Preview1",
    "Preview2",
    "Preview3",
    "PreviewCreativeRequest",
    "PreviewCreativeRequest1",
    "PreviewCreativeRequest2",
    "PreviewCreativeRequest3",
    "PreviewCreativeResponse",
    "PreviewCreativeResponse1",
    "PreviewCreativeResponse2",
    "PreviewCreativeResponse3",
    "PreviewOutputFormat",
    "PreviewRender",
    "PreviewRender1",
    "PreviewRender2",
    "PreviewRender3",
    "Price",
    "PriceGuidance",
    "Pricing",
    "PricingModel",
    "PricingOption",
    "PrimaryCountry",
    "PrivacyPolicyAcknowledged",
    "Product",
    "ProductAllocation",
    "ProductCard",
    "ProductCardDetailed",
    "ProductCatalog",
    "ProductFilters",
    "PromotedOfferings",
    "PromotedOfferingsAssetRequirements",
    "PromotedOfferingsRequirement",
    "PromotedProducts",
    "Property",
    "PropertyError",
    "PropertyFeature",
    "PropertyFeatureDefinition",
    "PropertyId",
    "PropertyIdentifierTypes",
    "PropertyList",
    "PropertyListChangedWebhook",
    "PropertyListFilters",
    "PropertyListReference",
    "PropertyTag",
    "PropertyType",
    "Proposal",
    "Protocol",
    "ProtocolEnvelope",
    "ProtocolResponse",
    "Provenance",
    "ProvidePerformanceFeedbackRequest",
    "ProvidePerformanceFeedbackRequest1",
    "ProvidePerformanceFeedbackRequest2",
    "ProvidePerformanceFeedbackResponse",
    "ProvidePerformanceFeedbackResponse1",
    "ProvidePerformanceFeedbackResponse2",
    "Provider",
    "PublisherDomain",
    "PublisherIdentifierTypes",
    "PublisherPropertySelector",
    "PublisherPropertySelector1",
    "PublisherPropertySelector2",
    "PublisherPropertySelector3",
    "PushNotificationConfig",
    "QuartileData",
    "QuerySummary",
    "Radius",
    "Range",
    "ReachUnit",
    "RealEstateItem",
    "Reason",
    "Record",
    "Recovery",
    "ReferenceAsset",
    "Refine",
    "Refine1",
    "Refine2",
    "RefinementAppliedItem",
    "Region",
    "Renders",
    "Renders1",
    "ReportUsageRequest",
    "ReportUsageResponse",
    "Reporting",
    "ReportingCapabilities",
    "ReportingDimensions",
    "ReportingFrequency",
    "ReportingPeriod",
    "ReportingWebhook",
    "Request",
    "RequiredDisclosure",
    "RequiredGeoTargetingItem",
    "Response",
    "Response1",
    "Responsive",
    "Result",
    "Results",
    "Results1",
    "Role",
    "Salary",
    "SampleRate",
    "Sampling",
    "SamplingInfo",
    "Sandbox",
    "ScalarBinding",
    "ScanType",
    "Scope",
    "Security",
    "SelectionMode",
    "SessionStatus",
    "Setup",
    "ShippingAddress",
    "SiCapabilities",
    "SiGetOfferingRequest",
    "SiGetOfferingResponse",
    "SiIdentity",
    "SiInitiateSessionRequest",
    "SiInitiateSessionResponse",
    "SiSendMessageRequest",
    "SiSendMessageRequest1",
    "SiSendMessageRequest2",
    "SiSendMessageResponse",
    "SiTerminateSessionRequest",
    "SiTerminateSessionResponse",
    "SiUiElement",
    "Signal",
    "SignalCatalogType",
    "SignalDefinition",
    "SignalFilters",
    "SignalId",
    "SignalId2",
    "SignalId3",
    "SignalPricing",
    "SignalPricing1",
    "SignalPricing2",
    "SignalPricing3",
    "SignalPricingOption",
    "SignalPricingOption1",
    "SignalPricingOption2",
    "SignalPricingOption3",
    "SignalPricingOption4",
    "SignalPricingOption5",
    "SignalPricingOption6",
    "SignalPricingOption7",
    "SignalSource",
    "SignalTag",
    "SignalTags",
    "SignalTargeting",
    "SignalTargeting1",
    "SignalTargeting2",
    "SignalTargeting3",
    "SignalValueType",
    "Signals",
    "Snapshot",
    "SnapshotUnavailableReason",
    "SnippetType",
    "Sort",
    "SortApplied",
    "SortDirection",
    "SortMetric",
    "Spend",
    "SponsoredIntelligence",
    "Standard",
    "StandardEnum",
    "StartTiming",
    "Status",
    "StatusFilter",
    "StatusSummary",
    "Store",
    "StoreCatchment",
    "StoreItem",
    "SubAsset",
    "SubAsset1",
    "SubAsset2",
    "Summary",
    "SupportedBillingEnum",
    "SupportedIdentifierType",
    "SupportedMatchType",
    "SupportedMetric",
    "SupportedProtocol",
    "SupportedTarget",
    "SupportedTarget1",
    "SupportedViewDuration",
    "SyncAccountsRequest",
    "SyncAccountsResponse",
    "SyncAccountsResponse1",
    "SyncAccountsResponse2",
    "SyncAudiencesRequest",
    "SyncAudiencesResponse",
    "SyncAudiencesResponse1",
    "SyncAudiencesResponse2",
    "SyncCatalogsInputRequired",
    "SyncCatalogsRequest",
    "SyncCatalogsResponse",
    "SyncCatalogsResponse1",
    "SyncCatalogsResponse2",
    "SyncCatalogsSubmitted",
    "SyncCatalogsWorking",
    "SyncCreativesInputRequired",
    "SyncCreativesRequest",
    "SyncCreativesResponse",
    "SyncCreativesResponse1",
    "SyncCreativesResponse2",
    "SyncCreativesSubmitted",
    "SyncCreativesWorking",
    "SyncEventSourcesRequest",
    "SyncEventSourcesResponse",
    "SyncEventSourcesResponse1",
    "SyncEventSourcesResponse2",
    "Tag",
    "Tags",
    "Target",
    "Target1",
    "Target2",
    "Target3",
    "Target4",
    "TargetFrequency",
    "TargetFrequency1",
    "Targeting",
    "TargetingOverlay",
    "TaskStatus",
    "TaskType",
    "TerminationContext",
    "TextAsset",
    "TextAssetRequirements",
    "TimeBasedPricingOption",
    "TimeRange",
    "TimeUnit",
    "Tone",
    "TotalBudget",
    "TotalBudgetGuidance",
    "Totals",
    "Trademark",
    "TransactionIntent",
    "TranscriptSource",
    "TranscriptSource1",
    "Transform",
    "Transmission",
    "Transport",
    "TransportMode",
    "TravelTime",
    "TravelTime1",
    "TravelTime2",
    "TravelTime4",
    "TravelTime5",
    "Type",
    "Uid",
    "UidType",
    "Unit",
    "UniversalMacro",
    "UpdateContentStandardsRequest",
    "UpdateContentStandardsResponse",
    "UpdateContentStandardsResponse1",
    "UpdateContentStandardsResponse2",
    "UpdateFrequency",
    "UpdateMediaBuyInputRequired",
    "UpdateMediaBuyRequest",
    "UpdateMediaBuyRequest1",
    "UpdateMediaBuyRequest2",
    "UpdateMediaBuyResponse",
    "UpdateMediaBuyResponse1",
    "UpdateMediaBuyResponse2",
    "UpdateMediaBuySubmitted",
    "UpdateMediaBuyWorking",
    "UpdatePropertyListRequest",
    "UpdatePropertyListResponse",
    "UrlAsset",
    "UrlAssetRequirements",
    "UrlAssetType",
    "UsageItem",
    "User",
    "UserMatch",
    "UserMatch1",
    "UserMatch2",
    "UserMatch3",
    "UserMatch4",
    "UserMatch5",
    "ValidateContentDeliveryRequest",
    "ValidateContentDeliveryResponse",
    "ValidateContentDeliveryResponse1",
    "ValidateContentDeliveryResponse2",
    "ValidationMode",
    "Variant",
    "VastAsset",
    "VastAsset1",
    "VastAsset2",
    "VastAssetRequirements",
    "VastTrackingEvent",
    "VastVersion",
    "VcpmPricingOption",
    "VehicleItem",
    "VenueBreakdownItem",
    "Verdict",
    "VerificationItem",
    "Video",
    "VideoAsset",
    "VideoAssetRequirements",
    "VideoBitDepth",
    "ViewThreshold",
    "ViewThreshold1",
    "Viewability",
    "Visual",
    "Voice",
    "WcagLevel",
    "WebhookAsset",
    "WebhookAssetRequirements",
    "WebhookResponseType",
    "WebhookSecurityMethod",
    "_AudienceFromGetMediaBuyDeliveryRequest",
    "_AudienceFromSyncAudiencesRequest",
    "_AudienceFromSyncAudiencesResponse",
    "_DeliveryStatusFromGetMediaBuyDeliveryResponse",
    "_PackageFromPackage",
]


# Rebuild models with forward references
# This must happen AFTER all imports to resolve forward reference chains

# Import individual modules needed for rebuilding
from adcp.types import generated_poc  # noqa: F401

# Rebuild models that reference other models via forward refs
CreativeManifest.model_rebuild()
PreviewCreativeRequest1.model_rebuild()
PreviewCreativeRequest2.model_rebuild()
PreviewCreativeRequest.model_rebuild()



# generated by datamodel-codegen:
#   filename:  sponsored_intelligence/si_capabilities.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated, Any

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class A2ui(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    catalogs: Annotated[
        list[str] | None,
        Field(description="Supported A2UI component catalogs (e.g., 'si-standard', 'standard')"),
    ] = None
    supported: Annotated[bool | None, Field(description='Supports A2UI surface rendering')] = False


class Commerce(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    acp_checkout: Annotated[
        bool | None, Field(description='Supports ACP (Agentic Commerce Protocol) checkout handoff')
    ] = None


class StandardEnum(Enum):
    text = 'text'
    link = 'link'
    image = 'image'
    product_card = 'product_card'
    carousel = 'carousel'
    action_button = 'action_button'


class Components(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    extensions: Annotated[
        dict[str, Any] | None,
        Field(description='Platform-specific extensions (chatgpt_apps_sdk, maps, forms, etc.)'),
    ] = None
    standard: Annotated[
        list[StandardEnum] | None,
        Field(description='Standard components that all SI hosts must render'),
    ] = None


class Avatar(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    avatar_id: Annotated[str | None, Field(description='Brand avatar identifier')] = None
    provider: Annotated[
        str | None, Field(description='Avatar provider (d-id, heygen, synthesia, etc.)')
    ] = None


class Video(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    formats: Annotated[
        list[str] | None, Field(description='Supported video formats (mp4, webm, etc.)')
    ] = None
    max_duration_seconds: Annotated[int | None, Field(description='Maximum video duration')] = None


class Voice(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    provider: Annotated[
        str | None, Field(description='TTS provider (elevenlabs, openai, etc.)')
    ] = None
    voice_id: Annotated[str | None, Field(description='Brand voice identifier')] = None


class Modalities(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    avatar: Annotated[
        bool | Avatar | None, Field(description='Animated video presence with brand avatar')
    ] = None
    conversational: Annotated[
        bool | None, Field(description='Pure text exchange - the baseline modality')
    ] = True
    video: Annotated[bool | Video | None, Field(description='Brand video content playback')] = None
    voice: Annotated[
        bool | Voice | None, Field(description='Audio-based interaction using brand voice')
    ] = None


class SiCapabilities(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    a2ui: Annotated[A2ui | None, Field(description='A2UI (Agent-to-UI) capabilities')] = None
    commerce: Annotated[Commerce | None, Field(description='Commerce capabilities')] = None
    components: Annotated[Components | None, Field(description='Visual components supported')] = (
        None
    )
    mcp_apps: Annotated[
        bool | None, Field(description='Supports MCP Apps for rendering A2UI surfaces in iframes')
    ] = False
    modalities: Annotated[
        Modalities | None, Field(description='Interaction modalities supported')
    ] = None



# generated by datamodel-codegen:
#   filename:  core/requirements/asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import Field, RootModel

from . import (
    audio_asset_requirements,
    css_asset_requirements,
    daast_asset_requirements,
    html_asset_requirements,
    image_asset_requirements,
    javascript_asset_requirements,
    markdown_asset_requirements,
    text_asset_requirements,
    url_asset_requirements,
    vast_asset_requirements,
    video_asset_requirements,
    webhook_asset_requirements,
)


class AssetRequirements(
    RootModel[
        image_asset_requirements.ImageAssetRequirements
        | video_asset_requirements.VideoAssetRequirements
        | audio_asset_requirements.AudioAssetRequirements
        | text_asset_requirements.TextAssetRequirements
        | markdown_asset_requirements.MarkdownAssetRequirements
        | html_asset_requirements.HtmlAssetRequirements
        | css_asset_requirements.CssAssetRequirements
        | javascript_asset_requirements.JavascriptAssetRequirements
        | vast_asset_requirements.VastAssetRequirements
        | daast_asset_requirements.DaastAssetRequirements
        | url_asset_requirements.UrlAssetRequirements
        | webhook_asset_requirements.WebhookAssetRequirements
    ]
):
    root: Annotated[
        image_asset_requirements.ImageAssetRequirements
        | video_asset_requirements.VideoAssetRequirements
        | audio_asset_requirements.AudioAssetRequirements
        | text_asset_requirements.TextAssetRequirements
        | markdown_asset_requirements.MarkdownAssetRequirements
        | html_asset_requirements.HtmlAssetRequirements
        | css_asset_requirements.CssAssetRequirements
        | javascript_asset_requirements.JavascriptAssetRequirements
        | vast_asset_requirements.VastAssetRequirements
        | daast_asset_requirements.DaastAssetRequirements
        | url_asset_requirements.UrlAssetRequirements
        | webhook_asset_requirements.WebhookAssetRequirements,
        Field(
            description='Technical requirements for creative assets. The applicable schema is determined by the sibling asset_type field.',
            title='Asset Requirements',
        ),
    ]



# generated by datamodel-codegen:
#   filename:  content_standards/content_standards.json
#   timestamp: 2026-02-27T02:10:10+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import Field

from ..core import ext as ext_1
from ..core import pricing_option
from ..enums import channels
from . import artifact


class CalibrationExemplars(AdCPBaseModel):
    fail: Annotated[
        list[artifact.Artifact] | None,
        Field(description='Artifacts that fail the content standards'),
    ] = None
    pass_: Annotated[
        list[artifact.Artifact] | None,
        Field(alias='pass', description='Artifacts that pass the content standards'),
    ] = None


class ContentStandards(AdCPBaseModel):
    calibration_exemplars: Annotated[
        CalibrationExemplars | None,
        Field(
            description='Training/test set to calibrate policy interpretation. Provides concrete examples of pass/fail decisions.'
        ),
    ] = None
    channels_any: Annotated[
        list[channels.MediaChannel] | None,
        Field(
            description='Advertising channels. Standards apply to ANY of the listed channels (OR logic).',
            min_length=1,
        ),
    ] = None
    countries_all: Annotated[
        list[str] | None,
        Field(
            description='ISO 3166-1 alpha-2 country codes. Standards apply in ALL listed countries (AND logic).',
            min_length=1,
        ),
    ] = None
    ext: ext_1.ExtensionObject | None = None
    languages_any: Annotated[
        list[str] | None,
        Field(
            description="BCP 47 language tags (e.g., 'en', 'de', 'fr'). Standards apply to content in ANY of these languages (OR logic). Content in unlisted languages is not covered by these standards.",
            min_length=1,
        ),
    ] = None
    name: Annotated[
        str | None, Field(description='Human-readable name for this standards configuration')
    ] = None
    policy: Annotated[
        str | None,
        Field(
            description='Natural language policy describing acceptable and unacceptable content contexts. Used by LLMs and human reviewers to make judgments.'
        ),
    ] = None
    pricing_options: Annotated[
        list[pricing_option.PricingOption] | None,
        Field(
            description='Pricing options for this content standards service. The buyer passes the selected pricing_option_id in report_usage for billing verification.',
            min_length=1,
        ),
    ] = None
    standards_id: Annotated[
        str, Field(description='Unique identifier for this standards configuration')
    ]



# generated by datamodel-codegen:
#   filename:  core/reporting_capabilities.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..enums import available_metric, reporting_frequency
from . import geo_breakdown_support


class DateRangeSupport(Enum):
    date_range = 'date_range'
    lifetime_only = 'lifetime_only'


class ReportingCapabilities(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    available_metrics: Annotated[
        list[available_metric.AvailableMetric],
        Field(
            description="Metrics available in reporting. Impressions and spend are always implicitly included. When a creative format declares reported_metrics, buyers receive the intersection of these product-level metrics and the format's reported_metrics.",
            examples=[
                ['impressions', 'spend', 'clicks', 'video_completions'],
                ['impressions', 'spend', 'conversions'],
            ],
        ),
    ]
    available_reporting_frequencies: Annotated[
        list[reporting_frequency.ReportingFrequency],
        Field(description='Supported reporting frequency options', min_length=1),
    ]
    date_range_support: Annotated[
        DateRangeSupport,
        Field(
            description="Whether delivery data can be filtered to arbitrary date ranges. 'date_range' means the platform supports start_date/end_date parameters. 'lifetime_only' means the platform returns campaign lifetime totals and date range parameters are not accepted."
        ),
    ]
    expected_delay_minutes: Annotated[
        int,
        Field(
            description='Expected delay in minutes before reporting data becomes available (e.g., 240 for 4-hour delay)',
            examples=[240, 300, 1440],
            ge=0,
        ),
    ]
    supports_audience_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports audience segment breakdowns in delivery reporting (by_audience within by_package)'
        ),
    ] = None
    supports_creative_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports creative-level metric breakdowns in delivery reporting (by_creative within by_package)'
        ),
    ] = None
    supports_device_platform_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports device platform breakdowns in delivery reporting (by_device_platform within by_package)'
        ),
    ] = None
    supports_device_type_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports device type breakdowns in delivery reporting (by_device_type within by_package)'
        ),
    ] = None
    supports_geo_breakdown: Annotated[
        geo_breakdown_support.GeographicBreakdownSupport | None,
        Field(
            description='Geographic breakdown support for this product. Declares which geo levels and systems are available for by_geo reporting within by_package.'
        ),
    ] = None
    supports_keyword_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports keyword-level metric breakdowns in delivery reporting (by_keyword within by_package)'
        ),
    ] = None
    supports_placement_breakdown: Annotated[
        bool | None,
        Field(
            description='Whether this product supports placement breakdowns in delivery reporting (by_placement within by_package)'
        ),
    ] = None
    supports_webhooks: Annotated[
        bool,
        Field(description='Whether this product supports webhook-based reporting notifications'),
    ]
    timezone: Annotated[
        str,
        Field(
            description="Timezone for reporting periods. Use 'UTC' or IANA timezone (e.g., 'America/New_York'). Critical for daily/monthly frequency alignment.",
            examples=['UTC', 'America/New_York', 'Europe/London', 'America/Los_Angeles'],
        ),
    ]



# generated by datamodel-codegen:
#   filename:  core/format_id.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, ConfigDict, Field


class FormatId(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    agent_url: Annotated[
        AnyUrl,
        Field(
            description="URL of the agent that defines this format (e.g., 'https://creatives.adcontextprotocol.org' for standard formats, or 'https://publisher.com/.well-known/adcp/sales' for custom formats)"
        ),
    ]
    duration_ms: Annotated[
        float | None,
        Field(
            description='Duration in milliseconds for time-based formats (video, audio). When specified, creates a parameterized format ID. Omit to reference a template format without parameters.',
            ge=1.0,
        ),
    ] = None
    height: Annotated[
        int | None,
        Field(
            description='Height in pixels for visual formats. When specified, width must also be specified. Both fields together create a parameterized format ID for dimension-specific variants.',
            ge=1,
        ),
    ] = None
    id: Annotated[
        str,
        Field(
            description="Format identifier within the agent's namespace (e.g., 'display_static', 'video_hosted', 'audio_standard'). When used alone, references a template format. When combined with dimension/duration fields, creates a parameterized format ID for a specific variant.",
            pattern='^[a-zA-Z0-9_-]+$',
        ),
    ]
    width: Annotated[
        int | None,
        Field(
            description='Width in pixels for visual formats. When specified, height must also be specified. Both fields together create a parameterized format ID for dimension-specific variants.',
            ge=1,
        ),
    ] = None



"""Tests for .model_summary() method on response types.

These tests verify that response types return human-readable messages
suitable for MCP tool results, A2A task communications, and REST API responses.
"""

from __future__ import annotations

from adcp.types._generated import (
    ActivateSignalResponse1,
    ActivateSignalResponse2,
    BuildCreativeResponse1,
    BuildCreativeResponse2,
    CreateMediaBuyResponse1,
    CreateMediaBuyResponse2,
    GetMediaBuyDeliveryResponse,
    GetProductsResponse,
    GetSignalsResponse,
    ListCreativeFormatsResponse,
    ListCreativesResponse,
    PreviewCreativeResponse1,
    PreviewCreativeResponse2,
    ProvidePerformanceFeedbackResponse1,
    ProvidePerformanceFeedbackResponse2,
    SyncCreativesResponse1,
    SyncCreativesResponse2,
    UpdateMediaBuyResponse1,
    UpdateMediaBuyResponse2,
)


class TestGetProductsResponseMessage:
    """Tests for GetProductsResponse.model_summary()."""

    def test_singular_product(self):
        """Single product uses singular form."""
        response = GetProductsResponse.model_construct(
            products=[{"product_id": "p1", "name": "Test"}]
        )
        assert response.model_summary() == "Found 1 product matching your requirements."

    def test_multiple_products(self):
        """Multiple products uses plural form."""
        response = GetProductsResponse.model_construct(
            products=[
                {"product_id": "p1", "name": "Test 1"},
                {"product_id": "p2", "name": "Test 2"},
                {"product_id": "p3", "name": "Test 3"},
            ]
        )
        assert response.model_summary() == "Found 3 products matching your requirements."

    def test_zero_products(self):
        """Zero products uses conversational message."""
        response = GetProductsResponse.model_construct(products=[])
        assert response.model_summary() == "No products matched your requirements."


class TestListCreativeFormatsResponseMessage:
    """Tests for ListCreativeFormatsResponse.model_summary()."""

    def test_singular_format(self):
        """Single format uses singular form."""
        response = ListCreativeFormatsResponse.model_construct(
            formats=[{"format_id": "f1", "name": "Banner"}]
        )
        assert response.model_summary() == "Found 1 supported creative format."

    def test_multiple_formats(self):
        """Multiple formats uses plural form."""
        response = ListCreativeFormatsResponse.model_construct(
            formats=[
                {"format_id": "f1", "name": "Banner 1"},
                {"format_id": "f2", "name": "Banner 2"},
            ]
        )
        assert response.model_summary() == "Found 2 supported creative formats."


class TestGetSignalsResponseMessage:
    """Tests for GetSignalsResponse.model_summary()."""

    def test_singular_signal(self):
        """Single signal uses singular form."""
        response = GetSignalsResponse.model_construct(signals=[{"signal_id": "s1"}])
        assert response.model_summary() == "Found 1 signal available for targeting."

    def test_multiple_signals(self):
        """Multiple signals uses plural form."""
        response = GetSignalsResponse.model_construct(
            signals=[{"signal_id": "s1"}, {"signal_id": "s2"}]
        )
        assert response.model_summary() == "Found 2 signals available for targeting."


class TestListCreativesResponseMessage:
    """Tests for ListCreativesResponse.model_summary()."""

    def test_singular_creative(self):
        """Single creative uses singular form."""
        response = ListCreativesResponse.model_construct(creatives=[{"creative_id": "c1"}])
        assert response.model_summary() == "Found 1 creative in the system."

    def test_multiple_creatives(self):
        """Multiple creatives uses plural form."""
        response = ListCreativesResponse.model_construct(
            creatives=[{"creative_id": "c1"}, {"creative_id": "c2"}]
        )
        assert response.model_summary() == "Found 2 creatives in the system."


class TestCreateMediaBuyResponseMessage:
    """Tests for CreateMediaBuyResponse success/error variants."""

    def test_success_singular_package(self):
        """Success with single package."""
        response = CreateMediaBuyResponse1.model_construct(
            media_buy_id="mb_123",
            buyer_ref="ref_456",
            packages=[{"package_id": "pkg_1"}],
        )
        assert response.model_summary() == "Media buy mb_123 created with 1 package."

    def test_success_multiple_packages(self):
        """Success with multiple packages."""
        response = CreateMediaBuyResponse1.model_construct(
            media_buy_id="mb_456",
            buyer_ref="ref_789",
            packages=[{"package_id": "pkg_1"}, {"package_id": "pkg_2"}],
        )
        assert response.model_summary() == "Media buy mb_456 created with 2 packages."

    def test_error_singular(self):
        """Error with single error."""
        response = CreateMediaBuyResponse2.model_construct(
            errors=[{"code": "invalid", "message": "Failed"}]
        )
        assert response.model_summary() == "Media buy creation failed with 1 error."

    def test_error_multiple(self):
        """Error with multiple errors."""
        response = CreateMediaBuyResponse2.model_construct(
            errors=[
                {"code": "invalid", "message": "Error 1"},
                {"code": "invalid", "message": "Error 2"},
            ]
        )
        assert response.model_summary() == "Media buy creation failed with 2 errors."


class TestUpdateMediaBuyResponseMessage:
    """Tests for UpdateMediaBuyResponse success/error variants."""

    def test_success(self):
        """Success message includes media buy ID."""
        response = UpdateMediaBuyResponse1.model_construct(
            media_buy_id="mb_789",
            packages=[],
        )
        assert response.model_summary() == "Media buy mb_789 updated successfully."

    def test_error(self):
        """Error message includes error count."""
        response = UpdateMediaBuyResponse2.model_construct(
            errors=[{"code": "not_found", "message": "Not found"}]
        )
        assert response.model_summary() == "Media buy update failed with 1 error."


class TestSyncCreativesResponseMessage:
    """Tests for SyncCreativesResponse success/error variants."""

    def test_success_singular(self):
        """Success with single creative synced."""
        response = SyncCreativesResponse1.model_construct(
            creatives=[{"creative_id": "c1", "action": "created"}]
        )
        assert response.model_summary() == "Synced 1 creative successfully."

    def test_success_multiple(self):
        """Success with multiple creatives synced."""
        response = SyncCreativesResponse1.model_construct(
            creatives=[
                {"creative_id": "c1", "action": "created"},
                {"creative_id": "c2", "action": "updated"},
                {"creative_id": "c3", "action": "created"},
            ]
        )
        assert response.model_summary() == "Synced 3 creatives successfully."

    def test_error(self):
        """Error message includes error count."""
        response = SyncCreativesResponse2.model_construct(
            errors=[{"code": "sync_failed", "message": "Failed"}]
        )
        assert response.model_summary() == "Creative sync failed with 1 error."


class TestActivateSignalResponseMessage:
    """Tests for ActivateSignalResponse success/error variants."""

    def test_success(self):
        """Success message is simple confirmation."""
        response = ActivateSignalResponse1.model_construct(activation_status="active")
        assert response.model_summary() == "Signal activated successfully."

    def test_error(self):
        """Error message includes error count."""
        response = ActivateSignalResponse2.model_construct(
            errors=[{"code": "activation_failed", "message": "Failed"}]
        )
        assert response.model_summary() == "Signal activation failed with 1 error."


class TestPreviewCreativeResponseMessage:
    """Tests for PreviewCreativeResponse single/batch variants."""

    def test_single_singular(self):
        """Single request with one preview."""
        response = PreviewCreativeResponse1.model_construct(
            response_type="single",
            expires_at="2025-12-01T00:00:00Z",
            previews=[{"preview_id": "p1"}],
        )
        assert response.model_summary() == "Generated 1 preview."

    def test_single_multiple(self):
        """Single request with multiple previews."""
        response = PreviewCreativeResponse1.model_construct(
            response_type="single",
            expires_at="2025-12-01T00:00:00Z",
            previews=[{"preview_id": "p1"}, {"preview_id": "p2"}],
        )
        assert response.model_summary() == "Generated 2 previews."

    def test_batch_singular(self):
        """Batch request with one manifest."""
        response = PreviewCreativeResponse2.model_construct(
            response_type="batch",
            results=[{"manifest_id": "m1"}],
        )
        assert response.model_summary() == "Generated previews for 1 manifest."

    def test_batch_multiple(self):
        """Batch request with multiple manifests."""
        response = PreviewCreativeResponse2.model_construct(
            response_type="batch",
            results=[{"manifest_id": "m1"}, {"manifest_id": "m2"}],
        )
        assert response.model_summary() == "Generated previews for 2 manifests."


class TestBuildCreativeResponseMessage:
    """Tests for BuildCreativeResponse success/error variants."""

    def test_success(self):
        """Success message is simple confirmation."""
        response = BuildCreativeResponse1.model_construct(
            assets=[{"url": "https://example.com/asset"}]
        )
        assert response.model_summary() == "Creative built successfully."

    def test_error(self):
        """Error message includes error count."""
        response = BuildCreativeResponse2.model_construct(
            errors=[{"code": "build_failed", "message": "Failed"}]
        )
        assert response.model_summary() == "Creative build failed with 1 error."


class TestGetMediaBuyDeliveryResponseMessage:
    """Tests for GetMediaBuyDeliveryResponse.model_summary()."""

    def test_with_single_media_buy(self):
        """Response with single media buy delivery data."""
        response = GetMediaBuyDeliveryResponse.model_construct(
            media_buy_deliveries=[{"media_buy_id": "mb_123"}]
        )
        assert response.model_summary() == "Retrieved delivery data for 1 media buy."

    def test_with_multiple_media_buys(self):
        """Response with multiple media buy delivery data."""
        response = GetMediaBuyDeliveryResponse.model_construct(
            media_buy_deliveries=[
                {"media_buy_id": "mb_123"},
                {"media_buy_id": "mb_456"},
            ]
        )
        assert response.model_summary() == "Retrieved delivery data for 2 media buys."


class TestProvidePerformanceFeedbackResponseMessage:
    """Tests for ProvidePerformanceFeedbackResponse success/error variants."""

    def test_success(self):
        """Success message is simple confirmation."""
        response = ProvidePerformanceFeedbackResponse1.model_construct(acknowledged=True)
        assert response.model_summary() == "Performance feedback recorded successfully."

    def test_error(self):
        """Error message includes error count."""
        response = ProvidePerformanceFeedbackResponse2.model_construct(
            errors=[{"code": "feedback_failed", "message": "Failed"}]
        )
        assert response.model_summary() == "Performance feedback recording failed with 1 error."


class TestNonResponseTypeMessage:
    """Tests for .model_summary() on non-response types."""

    def test_request_type_returns_generic_message(self):
        """Request types return generic message with class name."""
        from adcp.types import ListCreativesRequest

        request = ListCreativesRequest()
        assert request.model_summary() == "ListCreativesRequest response"

    def test_str_returns_pydantic_default(self):
        """str() returns Pydantic's default representation for inspection."""
        from adcp.types import ListCreativesRequest

        request = ListCreativesRequest()
        result = str(request)
        # Should be Pydantic's default field=value format with actual field names
        assert "context=" in result
        assert "fields=" in result
        assert "filters=" in result



# generated by datamodel-codegen:
#   filename:  core/assets/markdown_asset.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ...enums import markdown_flavor as markdown_flavor_1


class MarkdownAsset(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    allow_raw_html: Annotated[
        bool | None,
        Field(
            description='Whether raw HTML blocks are allowed in the markdown. False recommended for security.'
        ),
    ] = False
    content: Annotated[
        str,
        Field(
            description='Markdown content following CommonMark spec with optional GitHub Flavored Markdown extensions'
        ),
    ]
    language: Annotated[str | None, Field(description="Language code (e.g., 'en', 'es', 'fr')")] = (
        None
    )
    markdown_flavor: Annotated[
        markdown_flavor_1.MarkdownFlavor | None,
        Field(
            description='Markdown flavor used. CommonMark for strict compatibility, GFM for tables/task lists/strikethrough.'
        ),
    ] = markdown_flavor_1.MarkdownFlavor.commonmark



# generated by datamodel-codegen:
#   filename:  enums/asset_content_type.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum


class AssetContentType(Enum):
    image = 'image'
    video = 'video'
    audio = 'audio'
    text = 'text'
    markdown = 'markdown'
    html = 'html'
    css = 'css'
    javascript = 'javascript'
    vast = 'vast'
    daast = 'daast'
    url = 'url'
    webhook = 'webhook'
    brief = 'brief'
    catalog = 'catalog'



# generated by datamodel-codegen:
#   filename:  core/assets/image_asset.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, ConfigDict, Field

from .. import provenance as provenance_1


class ImageAsset(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    alt_text: Annotated[str | None, Field(description='Alternative text for accessibility')] = None
    format: Annotated[
        str | None, Field(description='Image file format (jpg, png, gif, webp, etc.)')
    ] = None
    height: Annotated[int, Field(description='Height in pixels', ge=1)]
    provenance: Annotated[
        provenance_1.Provenance | None,
        Field(
            description='Provenance metadata for this asset, overrides manifest-level provenance'
        ),
    ] = None
    url: Annotated[AnyUrl, Field(description='URL to the image asset')]
    width: Annotated[int, Field(description='Width in pixels', ge=1)]



# generated by datamodel-codegen:
#   filename:  property/delete_property_list_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import ext as ext_1


class DeletePropertyListResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    deleted: Annotated[bool, Field(description='Whether the list was successfully deleted')]
    ext: ext_1.ExtensionObject | None = None
    list_id: Annotated[str, Field(description='ID of the deleted list')]



# generated by datamodel-codegen:
#   filename:  core/signal_id.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated, Literal

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, ConfigDict, Field, RootModel


class SignalId2(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    data_provider_domain: Annotated[
        str,
        Field(
            description="Domain of the data provider that owns this signal (e.g., 'polk.com', 'experian.com'). The signal definition is published at this domain's /.well-known/adagents.json",
            pattern='^[a-z0-9]([a-z0-9-]*[a-z0-9])?(\\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$',
        ),
    ]
    id: Annotated[
        str,
        Field(
            description="Signal identifier within the data provider's catalog (e.g., 'likely_tesla_buyers', 'income_100k_plus')",
            pattern='^[a-zA-Z0-9_-]+$',
        ),
    ]
    source: Annotated[
        Literal['catalog'],
        Field(
            description="Discriminator indicating this signal is from a data provider's published catalog"
        ),
    ]


class SignalId3(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    agent_url: Annotated[
        AnyUrl,
        Field(
            description="URL of the signals agent that provides this signal (e.g., 'https://liveramp.com/.well-known/adcp/signals')"
        ),
    ]
    id: Annotated[
        str,
        Field(
            description="Signal identifier within the agent's signal set (e.g., 'custom_auto_intenders')",
            pattern='^[a-zA-Z0-9_-]+$',
        ),
    ]
    source: Annotated[
        Literal['agent'],
        Field(
            description='Discriminator indicating this signal is native to the agent (not from a data provider catalog)'
        ),
    ]


class SignalId(RootModel[SignalId2 | SignalId3]):
    root: Annotated[
        SignalId2 | SignalId3,
        Field(
            description="Universal signal identifier. Uses 'source' as discriminator: 'catalog' for signals from a data provider's published catalog (verifiable), 'agent' for agent-native signals (not externally verifiable).",
            discriminator='source',
            title='Signal ID',
        ),
    ]



# generated by datamodel-codegen:
#   filename:  core/event.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, AwareDatetime, ConfigDict, Field

from ..enums import action_source as action_source_1
from ..enums import event_type as event_type_1
from . import event_custom_data
from . import ext as ext_1
from . import user_match as user_match_1


class Event(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    action_source: Annotated[
        action_source_1.ActionSource | None, Field(description='Where the event originated')
    ] = None
    custom_data: Annotated[
        event_custom_data.EventCustomData | None,
        Field(description='Event-specific data (value, currency, items, etc.)'),
    ] = None
    custom_event_name: Annotated[
        str | None, Field(description="Name for custom events (used when event_type is 'custom')")
    ] = None
    event_id: Annotated[
        str,
        Field(
            description='Unique identifier for deduplication (scoped to event_type + event_source_id)',
            max_length=256,
            min_length=1,
        ),
    ]
    event_source_url: Annotated[
        AnyUrl | None,
        Field(
            description="URL where the event occurred (required when action_source is 'website')"
        ),
    ] = None
    event_time: Annotated[
        AwareDatetime, Field(description='ISO 8601 timestamp when the event occurred')
    ]
    event_type: Annotated[event_type_1.EventType, Field(description='Standard event type')]
    ext: ext_1.ExtensionObject | None = None
    user_match: Annotated[
        user_match_1.UserMatch | None,
        Field(description='User identifiers for attribution matching'),
    ] = None



# generated by datamodel-codegen:
#   filename:  media_buy/build_creative_request.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from ..core import brand_ref
from ..core import context as context_1
from ..core import creative_manifest as creative_manifest_1
from ..core import ext as ext_1
from ..core import format_id


class BuildCreativeRequest(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    brand: Annotated[
        brand_ref.BrandReference | None,
        Field(
            description='Brand reference for creative generation. Resolved to full brand identity (colors, logos, tone) at execution time.'
        ),
    ] = None
    context: context_1.ContextObject | None = None
    creative_manifest: Annotated[
        creative_manifest_1.CreativeManifest | None,
        Field(
            description='Creative manifest to transform or generate from. For pure generation, this should include the target format_id and any required input assets. For transformation (e.g., resizing, reformatting), this is the complete creative to adapt.'
        ),
    ] = None
    ext: ext_1.ExtensionObject | None = None
    message: Annotated[
        str | None,
        Field(
            description='Natural language instructions for the transformation or generation. For pure generation, this is the creative brief. For transformation, this provides guidance on how to adapt the creative. For refinement, this describes the desired changes.'
        ),
    ] = None
    target_format_id: Annotated[
        format_id.FormatId,
        Field(
            description='Format ID to generate. The format definition specifies required input assets and output structure.'
        ),
    ]



# generated by datamodel-codegen:
#   filename:  core/requirements/vast_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class VastVersion(Enum):
    field_2_0 = '2.0'
    field_3_0 = '3.0'
    field_4_0 = '4.0'
    field_4_1 = '4.1'
    field_4_2 = '4.2'


class VastAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    vast_version: Annotated[VastVersion | None, Field(description='Required VAST version')] = None



# generated by datamodel-codegen:
#   filename:  enums/device_platform.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class DevicePlatform(Enum):
    ios = 'ios'
    android = 'android'
    windows = 'windows'
    macos = 'macos'
    linux = 'linux'
    chromeos = 'chromeos'
    tvos = 'tvos'
    tizen = 'tizen'
    webos = 'webos'
    fire_os = 'fire_os'
    roku_os = 'roku_os'
    unknown = 'unknown'



# generated by datamodel-codegen:
#   filename:  core/pricing_option.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import Field, RootModel

from ..pricing_options import (
    cpa_option,
    cpc_option,
    cpcv_option,
    cpm_option,
    cpp_option,
    cpv_option,
    flat_rate_option,
    time_option,
    vcpm_option,
)


class PricingOption(
    RootModel[
        cpm_option.CpmPricingOption
        | vcpm_option.VcpmPricingOption
        | cpc_option.CpcPricingOption
        | cpcv_option.CpcvPricingOption
        | cpv_option.CpvPricingOption
        | cpp_option.CppPricingOption
        | cpa_option.CpaPricingOption
        | flat_rate_option.FlatRatePricingOption
        | time_option.TimeBasedPricingOption
    ]
):
    root: Annotated[
        cpm_option.CpmPricingOption
        | vcpm_option.VcpmPricingOption
        | cpc_option.CpcPricingOption
        | cpcv_option.CpcvPricingOption
        | cpv_option.CpvPricingOption
        | cpp_option.CppPricingOption
        | cpa_option.CpaPricingOption
        | flat_rate_option.FlatRatePricingOption
        | time_option.TimeBasedPricingOption,
        Field(
            description="A pricing model option offered by a publisher for a product. Discriminated by pricing_model field. If fixed_price is present, it's fixed pricing. If absent, it's auction-based (floor_price and price_guidance optional). Bid-based auction models may also include max_bid as a boolean signal to interpret bid_price as a buyer ceiling instead of an exact honored price.",
            title='Pricing Option',
        ),
    ]



# generated by datamodel-codegen:
#   filename:  core/requirements/video_asset_requirements.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field, RootModel


class Codec(Enum):
    h264 = 'h264'
    h265 = 'h265'
    vp8 = 'vp8'
    vp9 = 'vp9'
    av1 = 'av1'


class Container(Enum):
    mp4 = 'mp4'
    webm = 'webm'
    mov = 'mov'
    avi = 'avi'
    mkv = 'mkv'


class FrameRate(RootModel[float]):
    root: Annotated[float, Field(ge=1.0)]


class VideoAssetRequirements(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    aspect_ratio: Annotated[
        str | None,
        Field(description="Required aspect ratio (e.g., '16:9', '9:16')", pattern='^\\d+:\\d+$'),
    ] = None
    audio_required: Annotated[
        bool | None, Field(description='Whether the video must include an audio track')
    ] = None
    codecs: Annotated[list[Codec] | None, Field(description='Accepted video codecs')] = None
    containers: Annotated[
        list[Container] | None, Field(description='Accepted video container formats')
    ] = None
    frame_rates: Annotated[
        list[FrameRate] | None,
        Field(description='Accepted frame rates in frames per second (e.g., [24, 30, 60])'),
    ] = None
    max_bitrate_kbps: Annotated[
        int | None, Field(description='Maximum video bitrate in kilobits per second', ge=1)
    ] = None
    max_duration_ms: Annotated[
        int | None, Field(description='Maximum duration in milliseconds', ge=1)
    ] = None
    max_file_size_kb: Annotated[
        int | None, Field(description='Maximum file size in kilobytes', ge=1)
    ] = None
    max_height: Annotated[int | None, Field(description='Maximum height in pixels', ge=1)] = None
    max_width: Annotated[int | None, Field(description='Maximum width in pixels', ge=1)] = None
    min_bitrate_kbps: Annotated[
        int | None, Field(description='Minimum video bitrate in kilobits per second', ge=1)
    ] = None
    min_duration_ms: Annotated[
        int | None, Field(description='Minimum duration in milliseconds', ge=1)
    ] = None
    min_height: Annotated[int | None, Field(description='Minimum height in pixels', ge=1)] = None
    min_width: Annotated[int | None, Field(description='Minimum width in pixels', ge=1)] = None



# generated by datamodel-codegen:
#   filename:  account/sync_accounts_response.json
#   timestamp: 2026-02-27T02:10:10+00:00

from __future__ import annotations

from enum import Enum
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, AwareDatetime, ConfigDict, Field, RootModel

from ..core import brand_ref
from ..core import context as context_1
from ..core import error
from ..core import ext as ext_1


class AccountScope(Enum):
    operator = 'operator'
    brand = 'brand'
    operator_brand = 'operator_brand'
    agent = 'agent'


class Action(Enum):
    created = 'created'
    updated = 'updated'
    unchanged = 'unchanged'
    failed = 'failed'


class Billing(Enum):
    operator = 'operator'
    agent = 'agent'


class CreditLimit(AdCPBaseModel):
    amount: Annotated[float, Field(ge=0.0)]
    currency: Annotated[str, Field(pattern='^[A-Z]{3}$')]


class Setup(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    expires_at: Annotated[
        AwareDatetime | None, Field(description='When this setup link expires')
    ] = None
    message: Annotated[str, Field(description="Human-readable description of what's needed")]
    url: Annotated[
        AnyUrl | None,
        Field(
            description='URL where the human can complete the required action (credit application, legal agreement, add funds)'
        ),
    ] = None


class Status(Enum):
    active = 'active'
    pending_approval = 'pending_approval'
    rejected = 'rejected'
    payment_required = 'payment_required'
    suspended = 'suspended'
    closed = 'closed'


class Account(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    account_scope: Annotated[
        AccountScope | None,
        Field(
            description="How the seller scoped this account. operator: shared across all brands for this operator. brand: shared across all operators for this brand. operator_brand: dedicated to this operator+brand pair. agent: the agent's default account."
        ),
    ] = None
    action: Annotated[
        Action,
        Field(
            description='Action taken for this account. created: new account provisioned. updated: existing account modified. unchanged: no changes needed. failed: could not process (see errors).'
        ),
    ]
    billing: Annotated[
        Billing | None,
        Field(description='Who is invoiced on this account. Matches the requested billing model.'),
    ] = None
    brand: Annotated[
        brand_ref.BrandReference, Field(description='Brand reference, echoed from the request')
    ]
    credit_limit: CreditLimit | None = None
    errors: Annotated[
        list[error.Error] | None,
        Field(description="Per-account errors (only present when action is 'failed')"),
    ] = None
    name: Annotated[
        str | None, Field(description='Human-readable account name assigned by the seller')
    ] = None
    operator: Annotated[str, Field(description='Operator domain, echoed from request')]
    payment_terms: Annotated[
        str | None, Field(description="Payment terms (e.g., 'net_30', 'prepay')")
    ] = None
    rate_card: Annotated[str | None, Field(description='Rate card applied to this account')] = None
    sandbox: Annotated[
        bool | None,
        Field(description='Whether this is a sandbox account, echoed from the request.'),
    ] = None
    setup: Annotated[
        Setup | None,
        Field(
            description='Setup information for pending accounts. Provides the agent (or human) with next steps to complete account activation.'
        ),
    ] = None
    status: Annotated[
        Status,
        Field(
            description='Account status. active: ready for use. pending_approval: seller reviewing (credit, legal). rejected: seller declined the account request. payment_required: credit limit reached or funds depleted. suspended: was active, now paused. closed: was active, now terminated.'
        ),
    ]
    warnings: Annotated[
        list[str] | None, Field(description='Non-fatal warnings about this account')
    ] = None


class SyncAccountsResponse1(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    accounts: Annotated[list[Account], Field(description='Results for each account processed')]
    context: context_1.ContextObject | None = None
    dry_run: Annotated[
        bool | None, Field(description='Whether this was a dry run (no actual changes made)')
    ] = None
    ext: ext_1.ExtensionObject | None = None


class SyncAccountsResponse2(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    context: context_1.ContextObject | None = None
    errors: Annotated[
        list[error.Error],
        Field(
            description='Operation-level errors (e.g., authentication failure, service unavailable)',
            min_length=1,
        ),
    ]
    ext: ext_1.ExtensionObject | None = None


class SyncAccountsResponse(RootModel[SyncAccountsResponse1 | SyncAccountsResponse2]):
    root: Annotated[
        SyncAccountsResponse1 | SyncAccountsResponse2,
        Field(
            description='Response from account sync operation. Returns per-account results with status and billing, or operation-level errors on complete failure.',
            examples=[
                {
                    'data': {
                        'accounts': [
                            {
                                'account_scope': 'operator_brand',
                                'action': 'created',
                                'billing': 'operator',
                                'brand': {'brand_id': 'spark', 'domain': 'nova-brands.com'},
                                'name': 'Spark (via Pinnacle)',
                                'operator': 'pinnacle-media.com',
                                'status': 'active',
                            },
                            {
                                'account_scope': 'operator_brand',
                                'action': 'created',
                                'billing': 'operator',
                                'brand': {'brand_id': 'glow', 'domain': 'nova-brands.com'},
                                'name': 'Glow',
                                'operator': 'pinnacle-media.com',
                                'setup': {
                                    'expires_at': '2026-03-10T00:00:00Z',
                                    'message': 'Complete advertiser registration and credit application',
                                    'url': 'https://seller.example.com/advertiser-onboard',
                                },
                                'status': 'pending_approval',
                            },
                        ]
                    },
                    'description': 'Mixed results — one active, one pending approval',
                },
                {
                    'data': {
                        'accounts': [
                            {
                                'action': 'created',
                                'brand': {'brand_id': 'clearance', 'domain': 'acme-corp.com'},
                                'operator': 'acme-corp.com',
                                'status': 'rejected',
                                'warnings': [
                                    'Account request declined: advertiser category not accepted on this platform.'
                                ],
                            }
                        ]
                    },
                    'description': 'Rejected account — no account_id assigned',
                },
                {
                    'data': {
                        'accounts': [
                            {
                                'action': 'failed',
                                'brand': {'domain': 'acme-corp.com'},
                                'errors': [
                                    {
                                        'code': 'BILLING_NOT_SUPPORTED',
                                        'message': 'Operator billing is not supported. This seller only accepts agent billing.',
                                    }
                                ],
                                'operator': 'acme-corp.com',
                                'status': 'rejected',
                            }
                        ]
                    },
                    'description': 'Unsupported billing — seller rejects the request',
                },
            ],
            title='Sync Accounts Response',
        ),
    ]



# generated by datamodel-codegen:
#   filename:  core/creative_variant.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field

from . import creative_manifest
from . import ext as ext_1
from . import identifier
from .delivery_metrics import DeliveryMetrics


class Artifact(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    artifact_id: Annotated[str, Field(description='Artifact identifier within the property')]
    property_id: Annotated[
        identifier.Identifier, Field(description='Property where the artifact appears')
    ]


class GenerationContext(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    artifact: Annotated[
        Artifact | None,
        Field(
            description='Reference to the content-standards artifact that provided the generation context. Links this variant to the specific piece of content (article, video, podcast segment, etc.) where the ad was placed.'
        ),
    ] = None
    context_type: Annotated[
        str | None,
        Field(
            description="Type of context that triggered generation (e.g., 'web_page', 'conversational', 'search', 'app', 'dooh')"
        ),
    ] = None
    ext: ext_1.ExtensionObject | None = None


class CreativeVariant(DeliveryMetrics):
    generation_context: Annotated[
        GenerationContext | None,
        Field(
            description='Input signals that triggered generation of this variant (Tier 3). Describes why the platform created this specific variant. Platforms should provide summarized or anonymized signals rather than raw user input. For web contexts, may include page topic or URL. For conversational contexts, an anonymized content signal. For search, query category or intent. When the content context is managed through AdCP content standards, reference the artifact directly via the artifact field.'
        ),
    ] = None
    manifest: Annotated[
        creative_manifest.CreativeManifest | None,
        Field(
            description='The rendered creative manifest for this variant — the actual output that was served, not the input assets. Contains format_id and the resolved assets (specific headline, image, video, etc. the platform selected or generated). For Tier 2, shows which asset combination was picked. For Tier 3, contains the generated assets which may differ entirely from the input brand identity. Pass to preview_creative to re-render.'
        ),
    ] = None
    variant_id: Annotated[str, Field(description='Platform-assigned identifier for this variant')]



# generated by datamodel-codegen:
#   filename:  enums/demographic_system.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from enum import Enum


class DemographicSystem(Enum):
    nielsen = 'nielsen'
    barb = 'barb'
    agf = 'agf'
    oztam = 'oztam'
    mediametrie = 'mediametrie'
    custom = 'custom'



from __future__ import annotations

"""Tests for response parsing utilities."""

import json

import pytest
from pydantic import BaseModel, Field

from adcp.utils.response_parser import parse_json_or_text, parse_mcp_content


class SampleResponse(BaseModel):
    """Sample response type for testing."""

    message: str
    count: int
    items: list[str] = Field(default_factory=list)


class TestParseMCPContent:
    """Tests for parse_mcp_content function."""

    def test_parse_text_content_with_json(self):
        """Test parsing MCP text content containing JSON."""
        content = [
            {
                "type": "text",
                "text": json.dumps({"message": "Hello", "count": 42, "items": ["a", "b"]}),
            }
        ]

        result = parse_mcp_content(content, SampleResponse)

        assert isinstance(result, SampleResponse)
        assert result.message == "Hello"
        assert result.count == 42
        assert result.items == ["a", "b"]

    def test_parse_multiple_content_items(self):
        """Test parsing MCP content with multiple items, returns first valid."""
        content = [
            {"type": "text", "text": "Not JSON"},
            {
                "type": "text",
                "text": json.dumps({"message": "Valid", "count": 10}),
            },
        ]

        result = parse_mcp_content(content, SampleResponse)

        assert result.message == "Valid"
        assert result.count == 10

    def test_empty_content_raises_error(self):
        """Test that empty content array raises ValueError."""
        with pytest.raises(ValueError, match="Empty MCP content array"):
            parse_mcp_content([], SampleResponse)

    def test_no_valid_content_raises_error(self):
        """Test that content with no valid data raises ValueError."""
        content = [
            {"type": "text", "text": "Not JSON"},
            {"type": "other", "data": "something"},
        ]

        with pytest.raises(ValueError, match="No valid SampleResponse data found"):
            parse_mcp_content(content, SampleResponse)

    def test_invalid_schema_raises_error(self):
        """Test that content not matching schema raises ValueError."""
        content = [
            {
                "type": "text",
                "text": json.dumps({"wrong_field": "value"}),
            }
        ]

        with pytest.raises(ValueError, match="doesn't match expected schema"):
            parse_mcp_content(content, SampleResponse)

    def test_empty_text_content_skipped(self):
        """Test that empty text content is skipped."""
        content = [
            {"type": "text", "text": ""},
            {
                "type": "text",
                "text": json.dumps({"message": "Found", "count": 5}),
            },
        ]

        result = parse_mcp_content(content, SampleResponse)
        assert result.message == "Found"


class TestParseJSONOrText:
    """Tests for parse_json_or_text function."""

    def test_parse_dict_directly(self):
        """Test parsing dict data directly."""
        data = {"message": "Hello", "count": 42}

        result = parse_json_or_text(data, SampleResponse)

        assert result.message == "Hello"
        assert result.count == 42

    def test_parse_json_string(self):
        """Test parsing JSON string."""
        data = json.dumps({"message": "World", "count": 100})

        result = parse_json_or_text(data, SampleResponse)

        assert result.message == "World"
        assert result.count == 100

    def test_invalid_json_string_raises_error(self):
        """Test that invalid JSON string raises ValueError."""
        with pytest.raises(ValueError, match="not valid JSON"):
            parse_json_or_text("Not JSON at all", SampleResponse)

    def test_dict_not_matching_schema_raises_error(self):
        """Test that dict not matching schema raises ValueError."""
        with pytest.raises(ValueError, match="doesn't match expected schema"):
            parse_json_or_text({"wrong": "data"}, SampleResponse)

    def test_unsupported_type_raises_error(self):
        """Test that unsupported data type raises ValueError."""
        with pytest.raises(ValueError, match="Cannot parse response of type"):
            parse_json_or_text(12345, SampleResponse)  # type: ignore[arg-type]

    def test_json_string_not_matching_schema_raises_error(self):
        """Test that JSON string not matching schema raises ValueError."""
        data = json.dumps({"invalid": "structure"})

        with pytest.raises(ValueError, match="doesn't match expected schema"):
            parse_json_or_text(data, SampleResponse)


class ProductResponse(BaseModel):
    """Response type without protocol fields for testing protocol field stripping."""

    products: list[str]
    total: int = 0


class TestProtocolFieldExtraction:
    """Tests for protocol field extraction from A2A responses.

    A2A servers may include protocol-level fields (message, context_id, data)
    that are not part of task-specific response schemas. These are separated
    for task data validation, but preserved at the TaskResult level.

    See: https://github.com/adcontextprotocol/adcp-client-python/issues/109
    """

    def test_response_with_message_field_separated(self):
        """Test that protocol 'message' field is separated before validation."""
        # A2A server returns task data with protocol message mixed in
        data = {
            "message": "No products matched your requirements.",
            "products": ["product-1", "product-2"],
            "total": 2,
        }

        result = parse_json_or_text(data, ProductResponse)

        assert isinstance(result, ProductResponse)
        assert result.products == ["product-1", "product-2"]
        assert result.total == 2

    def test_response_with_context_id_separated(self):
        """Test that protocol 'context_id' field is separated before validation."""
        data = {
            "context_id": "session-123",
            "products": ["product-1"],
            "total": 1,
        }

        result = parse_json_or_text(data, ProductResponse)

        assert isinstance(result, ProductResponse)
        assert result.products == ["product-1"]

    def test_response_with_multiple_protocol_fields_separated(self):
        """Test that multiple protocol fields are separated."""
        data = {
            "message": "Found products",
            "context_id": "session-456",
            "products": ["a", "b", "c"],
            "total": 3,
        }

        result = parse_json_or_text(data, ProductResponse)

        assert isinstance(result, ProductResponse)
        assert result.products == ["a", "b", "c"]
        assert result.total == 3

    def test_response_with_data_wrapper_extracted(self):
        """Test that ProtocolResponse 'data' wrapper is extracted."""
        # Full ProtocolResponse format: {"message": "...", "data": {...task_data...}}
        data = {
            "message": "Operation completed",
            "context_id": "ctx-789",
            "data": {
                "products": ["wrapped-product"],
                "total": 1,
            },
        }

        result = parse_json_or_text(data, ProductResponse)

        assert isinstance(result, ProductResponse)
        assert result.products == ["wrapped-product"]
        assert result.total == 1

    def test_response_with_payload_wrapper_extracted(self):
        """Test that ProtocolEnvelope 'payload' wrapper is extracted."""
        # Full ProtocolEnvelope format
        data = {
            "message": "Operation completed",
            "status": "completed",
            "task_id": "task-123",
            "timestamp": "2025-01-01T00:00:00Z",
            "payload": {
                "products": ["envelope-product"],
                "total": 1,
            },
        }

        result = parse_json_or_text(data, ProductResponse)

        assert isinstance(result, ProductResponse)
        assert result.products == ["envelope-product"]
        assert result.total == 1

    def test_exact_match_still_works(self):
        """Test that responses exactly matching schema still work."""
        data = {
            "products": ["exact-match"],
            "total": 1,
        }

        result = parse_json_or_text(data, ProductResponse)

        assert result.products == ["exact-match"]
        assert result.total == 1

    def test_json_string_with_protocol_fields(self):
        """Test JSON string with protocol fields is parsed correctly."""
        data = json.dumps(
            {
                "message": "Success",
                "products": ["from-json-string"],
                "total": 1,
            }
        )

        result = parse_json_or_text(data, ProductResponse)

        assert result.products == ["from-json-string"]

    def test_invalid_data_after_separation_raises_error(self):
        """Test that invalid data still raises error after separation."""
        data = {
            "message": "Some message",
            "wrong_field": "value",
        }

        with pytest.raises(ValueError, match="doesn't match expected schema"):
            parse_json_or_text(data, ProductResponse)

    def test_model_with_message_field_validates_directly(self):
        """Test that models containing 'message' field validate without separation."""
        # SampleResponse has a 'message' field, so it should validate directly
        data = {
            "message": "Hello",
            "count": 42,
        }

        result = parse_json_or_text(data, SampleResponse)

        assert result.message == "Hello"
        assert result.count == 42



# generated by datamodel-codegen:
#   filename:  sponsored_intelligence/si_get_offering_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AnyUrl, AwareDatetime, ConfigDict, Field

from ..core import error
from ..core import ext as ext_1


class MatchingProduct(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    availability_summary: Annotated[
        str | None,
        Field(
            description="Brief availability info (e.g., 'In stock', 'Size 14 available', '3 left')"
        ),
    ] = None
    image_url: Annotated[AnyUrl | None, Field(description='Product image')] = None
    name: Annotated[str, Field(description='Product name')]
    original_price: Annotated[str | None, Field(description='Original price if on sale')] = None
    price: Annotated[str | None, Field(description="Display price (e.g., '$129', '$89.99')")] = None
    product_id: Annotated[str, Field(description='Product identifier')]
    url: Annotated[AnyUrl | None, Field(description='Product detail page URL')] = None


class Offering(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    expires_at: Annotated[AwareDatetime | None, Field(description='When this offering expires')] = (
        None
    )
    image_url: Annotated[AnyUrl | None, Field(description='Hero image for the offering')] = None
    landing_url: Annotated[AnyUrl | None, Field(description='Landing page URL')] = None
    offering_id: Annotated[str | None, Field(description='Offering identifier')] = None
    price_hint: Annotated[
        str | None, Field(description="Price indication (e.g., 'from $199', '50% off')")
    ] = None
    summary: Annotated[str | None, Field(description='Brief summary of the offering')] = None
    tagline: Annotated[str | None, Field(description='Short promotional tagline')] = None
    title: Annotated[str | None, Field(description='Offering title')] = None


class SiGetOfferingResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    alternative_offering_ids: Annotated[
        list[str] | None,
        Field(description='Alternative offerings to consider if this one is unavailable'),
    ] = None
    available: Annotated[bool, Field(description='Whether the offering is currently available')]
    checked_at: Annotated[
        AwareDatetime | None, Field(description='When this offering information was retrieved')
    ] = None
    errors: Annotated[
        list[error.Error] | None, Field(description='Errors during offering lookup')
    ] = None
    ext: ext_1.ExtensionObject | None = None
    matching_products: Annotated[
        list[MatchingProduct] | None,
        Field(
            description='Products matching the request context. Only included if include_products was true.'
        ),
    ] = None
    offering: Annotated[Offering | None, Field(description='Offering details')] = None
    offering_token: Annotated[
        str | None,
        Field(
            description="Token to pass to si_initiate_session for session continuity. Brand stores the full query context server-side (products shown, order, context) so they can resolve references like 'the second one' when the session starts."
        ),
    ] = None
    total_matching: Annotated[
        int | None,
        Field(
            description='Total number of products matching the context (may be more than returned in matching_products)',
            ge=0,
        ),
    ] = None
    ttl_seconds: Annotated[
        int | None,
        Field(
            description='How long this offering information is valid (seconds). Host should re-fetch after TTL expires.',
            ge=0,
        ),
    ] = None
    unavailable_reason: Annotated[
        str | None,
        Field(
            description="If not available, why (e.g., 'expired', 'sold_out', 'region_restricted')"
        ),
    ] = None



# generated by datamodel-codegen:
#   filename:  core/forecast_range.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class ForecastRange(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    high: Annotated[
        float | None, Field(description='Optimistic (high-end) forecast value', ge=0.0)
    ] = None
    low: Annotated[
        float | None, Field(description='Conservative (low-end) forecast value', ge=0.0)
    ] = None
    mid: Annotated[float, Field(description='Expected (most likely) forecast value', ge=0.0)]



# generated by datamodel-codegen:
#   filename:  enums/error_code.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from enum import Enum


class ErrorCode(Enum):
    INVALID_REQUEST = 'INVALID_REQUEST'
    AUTH_REQUIRED = 'AUTH_REQUIRED'
    RATE_LIMITED = 'RATE_LIMITED'
    SERVICE_UNAVAILABLE = 'SERVICE_UNAVAILABLE'
    POLICY_VIOLATION = 'POLICY_VIOLATION'
    PRODUCT_NOT_FOUND = 'PRODUCT_NOT_FOUND'
    PRODUCT_UNAVAILABLE = 'PRODUCT_UNAVAILABLE'
    PROPOSAL_EXPIRED = 'PROPOSAL_EXPIRED'
    BUDGET_TOO_LOW = 'BUDGET_TOO_LOW'
    CREATIVE_REJECTED = 'CREATIVE_REJECTED'
    UNSUPPORTED_FEATURE = 'UNSUPPORTED_FEATURE'
    AUDIENCE_TOO_SMALL = 'AUDIENCE_TOO_SMALL'
    ACCOUNT_NOT_FOUND = 'ACCOUNT_NOT_FOUND'
    ACCOUNT_SETUP_REQUIRED = 'ACCOUNT_SETUP_REQUIRED'
    ACCOUNT_AMBIGUOUS = 'ACCOUNT_AMBIGUOUS'
    ACCOUNT_PAYMENT_REQUIRED = 'ACCOUNT_PAYMENT_REQUIRED'
    ACCOUNT_SUSPENDED = 'ACCOUNT_SUSPENDED'
    COMPLIANCE_UNSATISFIED = 'COMPLIANCE_UNSATISFIED'
    BUDGET_EXHAUSTED = 'BUDGET_EXHAUSTED'
    CONFLICT = 'CONFLICT'



# generated by datamodel-codegen:
#   filename:  core/date_range.json
#   timestamp: 2026-02-28T17:39:50+00:00

from __future__ import annotations

from datetime import date as date_aliased
from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class DateRange(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    end: Annotated[date_aliased, Field(description='End date (inclusive), ISO 8601')]
    start: Annotated[date_aliased, Field(description='Start date (inclusive), ISO 8601')]



"""Core type definitions."""

from __future__ import annotations

from enum import Enum
from typing import Any, Generic, Literal, TypeVar

from pydantic import BaseModel, ConfigDict, Field, field_validator, model_validator


class Protocol(str, Enum):
    """Supported protocols."""

    A2A = "a2a"
    MCP = "mcp"


class AgentConfig(BaseModel):
    """Agent configuration."""

    id: str
    agent_uri: str
    protocol: Protocol
    auth_token: str | None = None
    requires_auth: bool = False
    auth_header: str = "x-adcp-auth"  # Header name for authentication
    auth_type: str = "token"  # "token" for direct value, "bearer" for "Bearer {token}"
    timeout: float = 30.0  # Request timeout in seconds
    mcp_transport: str = (
        "streamable_http"  # "streamable_http" (default, modern) or "sse" (legacy fallback)
    )
    debug: bool = False  # Enable debug mode to capture request/response details

    @field_validator("agent_uri")
    @classmethod
    def validate_agent_uri(cls, v: str) -> str:
        """Validate agent URI format."""
        if not v:
            raise ValueError("agent_uri cannot be empty")

        if not v.startswith(("http://", "https://")):
            raise ValueError(
                f"agent_uri must start with http:// or https://, got: {v}\n"
                "Example: https://agent.example.com"
            )

        # Remove trailing slash for consistency
        return v.rstrip("/")

    @field_validator("timeout")
    @classmethod
    def validate_timeout(cls, v: float) -> float:
        """Validate timeout is reasonable."""
        if v <= 0:
            raise ValueError(f"timeout must be positive, got: {v}")

        if v > 300:  # 5 minutes
            raise ValueError(
                f"timeout is very large ({v}s). Consider a value under 300 seconds.\n"
                "Large timeouts can cause long hangs if agent is unresponsive."
            )

        return v

    @field_validator("mcp_transport")
    @classmethod
    def validate_mcp_transport(cls, v: str) -> str:
        """Validate MCP transport type."""
        valid_transports = ["streamable_http", "sse"]
        if v not in valid_transports:
            raise ValueError(
                f"mcp_transport must be one of {valid_transports}, got: {v}\n"
                "Use 'streamable_http' for modern agents (recommended)"
            )
        return v

    @field_validator("auth_type")
    @classmethod
    def validate_auth_type(cls, v: str) -> str:
        """Validate auth type."""
        valid_types = ["token", "bearer"]
        if v not in valid_types:
            raise ValueError(
                f"auth_type must be one of {valid_types}, got: {v}\n"
                "Use 'bearer' for OAuth2/standard Authorization header"
            )
        return v


class TaskStatus(str, Enum):
    """Task execution status."""

    COMPLETED = "completed"
    SUBMITTED = "submitted"
    NEEDS_INPUT = "needs_input"
    FAILED = "failed"
    WORKING = "working"


T = TypeVar("T")


class SubmittedInfo(BaseModel):
    """Information about submitted async task."""

    webhook_url: str
    operation_id: str


class NeedsInputInfo(BaseModel):
    """Information when agent needs clarification."""

    message: str
    field: str | None = None


class DebugInfo(BaseModel):
    """Debug information for troubleshooting."""

    request: dict[str, Any]
    response: dict[str, Any]
    duration_ms: float | None = None


class TaskResult(BaseModel, Generic[T]):
    """Result from task execution."""

    model_config = ConfigDict(arbitrary_types_allowed=True)

    status: TaskStatus
    data: T | None = None
    message: str | None = None  # Human-readable message from agent (e.g., MCP content text)
    submitted: SubmittedInfo | None = None
    needs_input: NeedsInputInfo | None = None
    error: str | None = None
    success: bool = Field(default=True)
    metadata: dict[str, Any] | None = None
    debug_info: DebugInfo | None = None


class ActivityType(str, Enum):
    """Types of activity events."""

    PROTOCOL_REQUEST = "protocol_request"
    PROTOCOL_RESPONSE = "protocol_response"
    WEBHOOK_RECEIVED = "webhook_received"
    HANDLER_CALLED = "handler_called"
    STATUS_CHANGE = "status_change"


class Activity(BaseModel):
    """Activity event for observability."""

    model_config = {"frozen": True}

    type: ActivityType
    operation_id: str
    agent_id: str
    task_type: str
    status: TaskStatus | None = None
    timestamp: str
    metadata: dict[str, Any] | None = None


class WebhookMetadata(BaseModel):
    """Metadata passed to webhook handlers."""

    operation_id: str
    agent_id: str
    task_type: str
    status: TaskStatus
    sequence_number: int | None = None
    notification_type: Literal["scheduled", "final", "delayed"] | None = None
    timestamp: str


class ResolvedBrand(BaseModel):
    """Brand identity resolved from the AdCP registry."""

    model_config = ConfigDict(extra="allow")

    canonical_id: str
    canonical_domain: str
    brand_name: str
    names: list[dict[str, str]] | None = None
    keller_type: str | None = None
    parent_brand: str | None = None
    house_domain: str | None = None
    house_name: str | None = None
    brand_agent_url: str | None = None
    brand: dict[str, Any] | None = None
    brand_manifest: dict[str, Any] | None = None
    source: str

    @model_validator(mode="before")
    @classmethod
    def _normalize_brand_fields(cls, data: Any) -> Any:
        """Cross-populate brand and brand_manifest so both names are always accessible."""
        if isinstance(data, dict):
            data = dict(data)
            if "brand" in data and "brand_manifest" not in data:
                data["brand_manifest"] = data["brand"]
            elif "brand_manifest" in data and "brand" not in data:
                data["brand"] = data["brand_manifest"]
        return data


class Member(BaseModel):
    """An organization registered in the AAO member directory."""

    model_config = ConfigDict(extra="allow")

    id: str
    slug: str
    display_name: str
    description: str | None = None
    tagline: str | None = None
    logo_url: str | None = None
    logo_light_url: str | None = None
    logo_dark_url: str | None = None
    contact_email: str | None = None
    contact_website: str | None = None
    offerings: list[str] = Field(default_factory=list)
    markets: list[str] = Field(default_factory=list)
    agents: list[dict[str, Any]] = Field(default_factory=list)
    brands: list[dict[str, Any]] = Field(default_factory=list)
    is_public: bool = True
    is_founding_member: bool = False
    featured: bool = False
    si_enabled: bool = False


class ResolvedProperty(BaseModel):
    """Property information resolved from the AdCP registry."""

    model_config = ConfigDict(extra="allow")

    publisher_domain: str
    source: str
    authorized_agents: list[dict[str, Any]]
    properties: list[dict[str, Any]]
    verified: bool



# generated by datamodel-codegen:
#   filename:  core/creative_filters.json
#   timestamp: 2026-02-27T02:10:10+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AwareDatetime, ConfigDict, Field

from ..enums import creative_status
from . import account_ref


class CreativeFilters(AdCPBaseModel):
    model_config = ConfigDict(
        extra='allow',
    )
    accounts: Annotated[
        list[account_ref.AccountReference] | None,
        Field(
            description='Filter creatives by owning accounts. Useful for agencies managing multiple client accounts.',
            min_length=1,
        ),
    ] = None
    assigned_to_packages: Annotated[
        list[str] | None,
        Field(description='Filter creatives assigned to any of these packages', min_length=1),
    ] = None
    buyer_refs: Annotated[
        list[str] | None,
        Field(
            description='Filter creatives assigned to media buys with any of these buyer references',
            min_length=1,
        ),
    ] = None
    created_after: Annotated[
        AwareDatetime | None,
        Field(description='Filter creatives created after this date (ISO 8601)'),
    ] = None
    created_before: Annotated[
        AwareDatetime | None,
        Field(description='Filter creatives created before this date (ISO 8601)'),
    ] = None
    creative_ids: Annotated[
        list[str] | None,
        Field(description='Filter by specific creative IDs', max_length=100, min_length=1),
    ] = None
    formats: Annotated[
        list[str] | None,
        Field(
            description='Filter by creative format types (e.g., video, audio, display)',
            min_length=1,
        ),
    ] = None
    has_performance_data: Annotated[
        bool | None, Field(description='Filter creatives that have performance data when true')
    ] = None
    media_buy_ids: Annotated[
        list[str] | None,
        Field(description='Filter creatives assigned to any of these media buys', min_length=1),
    ] = None
    name_contains: Annotated[
        str | None,
        Field(description='Filter by creative names containing this text (case-insensitive)'),
    ] = None
    statuses: Annotated[
        list[creative_status.CreativeStatus] | None,
        Field(description='Filter by creative approval statuses', min_length=1),
    ] = None
    tags: Annotated[
        list[str] | None,
        Field(description='Filter by creative tags (all tags must match)', min_length=1),
    ] = None
    tags_any: Annotated[
        list[str] | None,
        Field(description='Filter by creative tags (any tag must match)', min_length=1),
    ] = None
    unassigned: Annotated[
        bool | None,
        Field(
            description='Filter for unassigned creatives when true, assigned creatives when false'
        ),
    ] = None
    updated_after: Annotated[
        AwareDatetime | None,
        Field(description='Filter creatives last updated after this date (ISO 8601)'),
    ] = None
    updated_before: Annotated[
        AwareDatetime | None,
        Field(description='Filter creatives last updated before this date (ISO 8601)'),
    ] = None



# generated by datamodel-codegen:
#   filename:  core/start_timing.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated, Literal

from pydantic import AwareDatetime, Field, RootModel


class StartTiming(RootModel[Literal['asap'] | AwareDatetime]):
    root: Annotated[
        Literal['asap'] | AwareDatetime,
        Field(
            description="Campaign start timing: 'asap' or ISO 8601 date-time", title='Start Timing'
        ),
    ]



# generated by datamodel-codegen:
#   filename:  property/get_property_list_response.json
#   timestamp: 2026-02-23T01:56:40+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import AwareDatetime, ConfigDict, Field

from ..core import ext as ext_1
from ..core import identifier, pagination_response
from . import property_list


class GetPropertyListResponse(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    cache_valid_until: Annotated[
        AwareDatetime | None,
        Field(
            description='Cache expiration timestamp. Re-fetch the list after this time to get updated identifiers.'
        ),
    ] = None
    coverage_gaps: Annotated[
        dict[str, list[identifier.Identifier]] | None,
        Field(
            description="Properties included in the list despite missing feature data. Only present when a feature_requirement has if_not_covered='include'. Maps feature_id to list of identifiers not covered for that feature."
        ),
    ] = None
    ext: ext_1.ExtensionObject | None = None
    identifiers: Annotated[
        list[identifier.Identifier] | None,
        Field(
            description='Resolved identifiers that passed filters (if resolve=true). Cache these locally for real-time use.'
        ),
    ] = None
    list: Annotated[
        property_list.PropertyList,
        Field(description='The property list metadata (always returned)'),
    ]
    pagination: pagination_response.PaginationResponse | None = None
    resolved_at: Annotated[
        AwareDatetime | None, Field(description='When the list was resolved')
    ] = None
